[L] Change in libosmo-gprs[master]: gmm, rlcmac: Properly handle P-TMSI vs TLLI

2023-04-29 Thread fixeria
Attention is currently required from: pespin.

fixeria has posted comments on this change. ( 
https://gerrit.osmocom.org/c/libosmo-gprs/+/32507 )

Change subject: gmm, rlcmac: Properly handle P-TMSI vs TLLI
..


Patch Set 3: Code-Review+2


--
To view, visit https://gerrit.osmocom.org/c/libosmo-gprs/+/32507
To unsubscribe, or for help writing mail filters, visit 
https://gerrit.osmocom.org/settings

Gerrit-Project: libosmo-gprs
Gerrit-Branch: master
Gerrit-Change-Id: I44c95b3bc973b9dfcc79daf6b529fd2826f574e8
Gerrit-Change-Number: 32507
Gerrit-PatchSet: 3
Gerrit-Owner: pespin 
Gerrit-Reviewer: Jenkins Builder
Gerrit-Reviewer: fixeria 
Gerrit-Reviewer: laforge 
Gerrit-Reviewer: osmith 
Gerrit-Attention: pespin 
Gerrit-Comment-Date: Sun, 30 Apr 2023 05:57:30 +
Gerrit-HasComments: No
Gerrit-Has-Labels: Yes
Gerrit-MessageType: comment


[M] Change in osmo-bts[master]: gsm_objclass2obj(): Change signature/set NACK cause

2023-04-29 Thread fixeria
fixeria has submitted this change. ( 
https://gerrit.osmocom.org/c/osmo-bts/+/32354 )

Change subject: gsm_objclass2obj(): Change signature/set NACK cause
..

gsm_objclass2obj(): Change signature/set NACK cause

 - Add out-parameter to enable returning a NACK cause (ignored if NULL)
 - Return appropriate NACK cause if TRX number is unknown (fixes OS#5967
   together with change I37e6b23ed95260a8188910cf9754faffcba519c5)

Change-Id: If734ea2c8cae4c1f99b02520dffa4e3862a67745
Related: OS#5961, OS#5967
---
M include/osmo-bts/oml.h
M src/common/oml.c
M src/osmo-bts-trx/trx_provision_fsm.c
3 files changed, 44 insertions(+), 19 deletions(-)

Approvals:
  Jenkins Builder: Verified
  pespin: Looks good to me, but someone else must approve
  laforge: Looks good to me, but someone else must approve
  fixeria: Looks good to me, approved




diff --git a/include/osmo-bts/oml.h b/include/osmo-bts/oml.h
index add00c8..c35122e 100644
--- a/include/osmo-bts/oml.h
+++ b/include/osmo-bts/oml.h
@@ -82,6 +82,7 @@
enum abis_nm_nack_cause *c);

 void *gsm_objclass2obj(struct gsm_bts *bts, uint8_t obj_class,
-  const struct abis_om_obj_inst *obj_inst);
+  const struct abis_om_obj_inst *obj_inst,
+  enum abis_nm_nack_cause *c);

 #endif // _OML_H */
diff --git a/include/osmo-bts/oml.h b/include/osmo-bts/oml.h
index 38568b5..add00c8 100644
--- a/include/osmo-bts/oml.h
+++ b/include/osmo-bts/oml.h
@@ -78,7 +78,8 @@
 uint8_t obj_class, uint8_t p1, uint8_t p2, uint8_t p3);

 struct gsm_abis_mo *gsm_objclass2mo(struct gsm_bts *bts, uint8_t obj_class,
-   const struct abis_om_obj_inst *obj_inst);
+   const struct abis_om_obj_inst *obj_inst,
+   enum abis_nm_nack_cause *c);

 void *gsm_objclass2obj(struct gsm_bts *bts, uint8_t obj_class,
   const struct abis_om_obj_inst *obj_inst);
diff --git a/src/common/oml.c b/src/common/oml.c
index db95747..6bdb49b 100644
--- a/src/common/oml.c
+++ b/src/common/oml.c
@@ -534,6 +534,7 @@
const struct gsm_abis_mo *mo;
struct tlv_parsed tp;
int rc;
+   enum abis_nm_nack_cause c;

if (!foh || !bts)
return -EINVAL;
@@ -541,10 +542,9 @@
DEBUGPFOH(DOML, foh, "Rx GET ATTR\n");

/* Determine which OML object is addressed */
-   mo = gsm_objclass2mo(bts, foh->obj_class, >obj_inst);
-   if (!mo) {
+   if ((mo = gsm_objclass2mo(bts, foh->obj_class, >obj_inst, )) == 
NULL) {
LOGPFOH(DOML, LOGL_ERROR, foh, "Get Attributes for unknown 
Object Instance\n");
-   return oml_fom_ack_nack(msg, NM_NACK_OBJINST_UNKN);
+   return oml_fom_ack_nack(msg, c);
}

rc = oml_tlv_parse(, foh->data, msgb_l3len(msg) - sizeof(*foh));
@@ -1096,13 +1096,14 @@
struct gsm_abis_mo *mo;
void *obj;
int rc;
+   enum abis_nm_nack_cause c;

DEBUGPFOH(DOML, foh, "Rx OPSTART\n");

/* Step 1: Resolve MO by obj_class/obj_inst */
-   mo = gsm_objclass2mo(bts, foh->obj_class, >obj_inst);
-   obj = gsm_objclass2obj(bts, foh->obj_class, >obj_inst);
-   if (!mo || !obj)
+   if ((mo = gsm_objclass2mo(bts, foh->obj_class, >obj_inst, )) == 
NULL)
+   return oml_fom_ack_nack(msg, c);
+   if ((obj = gsm_objclass2obj(bts, foh->obj_class, >obj_inst)) == 
NULL)
return oml_fom_ack_nack(msg, NM_NACK_OBJINST_UNKN);

/* Step 2: Do some global dependency/consistency checking */
@@ -1128,6 +1129,7 @@
uint8_t adm_state;
void *obj;
int rc;
+   enum abis_nm_nack_cause c;

DEBUGPFOH(DOML, foh, "Rx CHG ADM STATE\n");

@@ -1145,9 +1147,9 @@
adm_state = *TLVP_VAL(, NM_ATT_ADM_STATE);

/* Step 1: Resolve MO by obj_class/obj_inst */
-   mo = gsm_objclass2mo(bts, foh->obj_class, >obj_inst);
-   obj = gsm_objclass2obj(bts, foh->obj_class, >obj_inst);
-   if (!mo || !obj)
+   if ((mo = gsm_objclass2mo(bts, foh->obj_class, >obj_inst, )) == 
NULL)
+   return oml_fom_ack_nack(msg, c);
+   if ((obj = gsm_objclass2obj(bts, foh->obj_class, >obj_inst)) == 
NULL)
return oml_fom_ack_nack(msg, NM_NACK_OBJINST_UNKN);

/* Step 2: Do some global dependency/consistency checking */
@@ -1473,23 +1475,23 @@
struct tlv_parsed tp, *tp_merged;
void *obj;
int rc;
+   enum abis_nm_nack_cause c;

DEBUGPFOH(DOML, foh, "Rx IPA SET ATTR\n");

rc = oml_tlv_parse(, foh->data, msgb_l3len(msg) - sizeof(*foh));
if (rc < 0) {
-   mo = gsm_objclass2mo(bts, foh->obj_class, >obj_inst);
-   if (!mo)
-   return oml_fom_ack_nack(msg, NM_NACK_OBJINST_UNKN);
+   if ((mo = gsm_objclass2mo(bts, foh->obj_class, >obj_inst, 
)) == NULL)
+   return oml_fom_ack_nack(msg, c);
oml_tx_failure_event_rep(mo, NM_SEVER_MAJOR, 
OSMO_EVT_MAJ_UNSUP_ATTR,
 "New value for IPAC Set Attribute not 
supported\n");
return oml_fom_ack_nack(msg, NM_NACK_INCORR_STRUCT);
}

/* Resolve MO by obj_class/obj_inst */
-   mo = gsm_objclass2mo(bts, foh->obj_class, >obj_inst);
-   obj = gsm_objclass2obj(bts, foh->obj_class, >obj_inst);
-   if (!mo || !obj)
+   if ((mo = 

[M] Change in osmo-bts[master]: gsm_objclass2obj(): Change signature/set NACK cause

2023-04-29 Thread fixeria
Attention is currently required from: arehbein.

fixeria has posted comments on this change. ( 
https://gerrit.osmocom.org/c/osmo-bts/+/32354 )

Change subject: gsm_objclass2obj(): Change signature/set NACK cause
..


Patch Set 4: Code-Review+2


--
To view, visit https://gerrit.osmocom.org/c/osmo-bts/+/32354
To unsubscribe, or for help writing mail filters, visit 
https://gerrit.osmocom.org/settings

Gerrit-Project: osmo-bts
Gerrit-Branch: master
Gerrit-Change-Id: If734ea2c8cae4c1f99b02520dffa4e3862a67745
Gerrit-Change-Number: 32354
Gerrit-PatchSet: 4
Gerrit-Owner: arehbein 
Gerrit-Reviewer: Jenkins Builder
Gerrit-Reviewer: fixeria 
Gerrit-Reviewer: laforge 
Gerrit-Reviewer: pespin 
Gerrit-Attention: arehbein 
Gerrit-Comment-Date: Sun, 30 Apr 2023 05:22:17 +
Gerrit-HasComments: No
Gerrit-Has-Labels: Yes
Gerrit-MessageType: comment


[M] Change in osmo-bts[master]: gsm_objclass2mo(): Change signature/set NACK cause

2023-04-29 Thread fixeria
Attention is currently required from: arehbein, pespin.

fixeria has posted comments on this change. ( 
https://gerrit.osmocom.org/c/osmo-bts/+/32075 )

Change subject: gsm_objclass2mo(): Change signature/set NACK cause
..


Patch Set 8: Code-Review+2


--
To view, visit https://gerrit.osmocom.org/c/osmo-bts/+/32075
To unsubscribe, or for help writing mail filters, visit 
https://gerrit.osmocom.org/settings

Gerrit-Project: osmo-bts
Gerrit-Branch: master
Gerrit-Change-Id: I37e6b23ed95260a8188910cf9754faffcba519c5
Gerrit-Change-Number: 32075
Gerrit-PatchSet: 8
Gerrit-Owner: arehbein 
Gerrit-Reviewer: Jenkins Builder
Gerrit-Reviewer: fixeria 
Gerrit-Reviewer: laforge 
Gerrit-Reviewer: pespin 
Gerrit-Attention: arehbein 
Gerrit-Attention: pespin 
Gerrit-Comment-Date: Sun, 30 Apr 2023 05:22:12 +
Gerrit-HasComments: No
Gerrit-Has-Labels: Yes
Gerrit-MessageType: comment


[S] Change in osmo-bsc[master]: gsm_bts_send_c0_power_red(): check if BTS is online first

2023-04-29 Thread fixeria
fixeria has submitted this change. ( 
https://gerrit.osmocom.org/c/osmo-bsc/+/32541 )

Change subject: gsm_bts_send_c0_power_red(): check if BTS is online first
..

gsm_bts_send_c0_power_red(): check if BTS is online first

... and print a proper error message instead of "not supported".  We
don't know for sure whether it's supported before the BTS is connected.

Change-Id: I080aa7ef331b76918ae48d555eea6e4290c57120
Related: SYS#6435
---
M src/osmo-bsc/bsc_vty.c
M src/osmo-bsc/bts.c
M src/osmo-bsc/bts_ctrl.c
3 files changed, 31 insertions(+), 8 deletions(-)

Approvals:
  pespin: Looks good to me, but someone else must approve
  Jenkins Builder: Verified
  laforge: Looks good to me, approved




diff --git a/src/osmo-bsc/bsc_vty.c b/src/osmo-bsc/bsc_vty.c
index f1bd7c4..34676a2 100644
--- a/src/osmo-bsc/bsc_vty.c
+++ b/src/osmo-bsc/bsc_vty.c
@@ -1426,18 +1426,22 @@
}

rc = gsm_bts_set_c0_power_red(bts, red);
-   if (rc == -ENOTSUP) {
+   switch (rc) {
+   case 0: /* success */
+   return CMD_SUCCESS;
+   case -ENOTCONN:
+   vty_out(vty, "%% BTS%u is offline%s", bts_nr, VTY_NEWLINE);
+   return CMD_WARNING;
+   case -ENOTSUP:
vty_out(vty, "%% BCCH carrier power reduction operation mode "
"is not supported for BTS%u%s", bts_nr, VTY_NEWLINE);
return CMD_WARNING;
-   } else if (rc != 0) {
+   default:
vty_out(vty, "%% Failed to %sable BCCH carrier power reduction "
"operation mode for BTS%u%s", red ? "en" : "dis",
bts_nr, VTY_NEWLINE);
return CMD_WARNING;
}
-
-   return CMD_SUCCESS;
 }

 /* this command is now hidden, as it's a low-level debug hack, and people 
should
diff --git a/src/osmo-bsc/bts.c b/src/osmo-bsc/bts.c
index be0516d..1ef9cca 100644
--- a/src/osmo-bsc/bts.c
+++ b/src/osmo-bsc/bts.c
@@ -981,6 +981,8 @@
 /* Send the given C0 power reduction value to the BTS */
 int gsm_bts_send_c0_power_red(const struct gsm_bts *bts, const uint8_t red)
 {
+   if (!bts_is_online(bts))
+   return -ENOTCONN;
if (!osmo_bts_has_feature(>features, BTS_FEAT_BCCH_POWER_RED))
return -ENOTSUP;
if (bts->model->power_ctrl_send_c0_power_red == NULL)
diff --git a/src/osmo-bsc/bts_ctrl.c b/src/osmo-bsc/bts_ctrl.c
index a971fab..5ac1e0d 100644
--- a/src/osmo-bsc/bts_ctrl.c
+++ b/src/osmo-bsc/bts_ctrl.c
@@ -497,15 +497,19 @@
int rc;

rc = gsm_bts_set_c0_power_red(bts, red);
-   if (rc == -ENOTSUP) {
+   switch (rc) {
+   case 0: /* success */
+   return get_bts_c0_power_red(cmd, data);
+   case -ENOTCONN:
+   cmd->reply = "BTS is offline";
+   return CTRL_CMD_ERROR;
+   case -ENOTSUP:
cmd->reply = "BCCH carrier power reduction is not supported";
return CTRL_CMD_ERROR;
-   } else if (rc != 0) {
+   default:
cmd->reply = "Failed to enable BCCH carrier power reduction";
return CTRL_CMD_ERROR;
}
-
-   return get_bts_c0_power_red(cmd, data);
 }

 CTRL_CMD_DEFINE(bts_c0_power_red, "c0-power-reduction");

--
To view, visit https://gerrit.osmocom.org/c/osmo-bsc/+/32541
To unsubscribe, or for help writing mail filters, visit 
https://gerrit.osmocom.org/settings

Gerrit-Project: osmo-bsc
Gerrit-Branch: master
Gerrit-Change-Id: I080aa7ef331b76918ae48d555eea6e4290c57120
Gerrit-Change-Number: 32541
Gerrit-PatchSet: 2
Gerrit-Owner: fixeria 
Gerrit-Reviewer: Jenkins Builder
Gerrit-Reviewer: fixeria 
Gerrit-Reviewer: laforge 
Gerrit-Reviewer: pespin 
Gerrit-MessageType: merged


[M] Change in osmo-bsc[master]: bts: st_op_enabled_on_enter(): resume C0 power reduction

2023-04-29 Thread fixeria
fixeria has submitted this change. ( 
https://gerrit.osmocom.org/c/osmo-bsc/+/32540 )

Change subject: bts: st_op_enabled_on_enter(): resume C0 power reduction
..

bts: st_op_enabled_on_enter(): resume C0 power reduction

If power saving is enabled for a BTS, it should remain enabled even
if the BTS is restarted for whatever reason.  This persistence can be
achieved by re-sending the configured power reduction value whenever
the BTS NM FSM enters the ENABLED state again (i.e. reconnects).

Separate gsm_bts_send_c0_power_red() from gsm_bts_set_c0_power_red()
and call the former from st_op_enabled_on_enter().  All we need to do
is to send the value that was configured before, per-timeslot power
reduction limits remain and need not to be updated.

Take a chance to move logging from BTS specific to the generic code.

Change-Id: Ic3f8a2ab0ffd049a8ed84361a3a588c1e1b23ac6
Related: SYS#6435
---
M include/osmocom/bsc/bts.h
M src/osmo-bsc/bts.c
M src/osmo-bsc/bts_osmobts.c
M src/osmo-bsc/nm_bts_fsm.c
4 files changed, 45 insertions(+), 10 deletions(-)

Approvals:
  Jenkins Builder: Verified
  pespin: Looks good to me, but someone else must approve
  laforge: Looks good to me, approved




diff --git a/include/osmocom/bsc/bts.h b/include/osmocom/bsc/bts.h
index 9b2aaab..78fc6a0 100644
--- a/include/osmocom/bsc/bts.h
+++ b/include/osmocom/bsc/bts.h
@@ -822,6 +822,7 @@

 int gsm_bts_set_system_infos(struct gsm_bts *bts);

+int gsm_bts_send_c0_power_red(const struct gsm_bts *bts, const uint8_t red);
 int gsm_bts_set_c0_power_red(struct gsm_bts *bts, const uint8_t red);

 void gsm_bts_stats_reset(struct gsm_bts *bts);
diff --git a/src/osmo-bsc/bts.c b/src/osmo-bsc/bts.c
index f5936c7..be0516d 100644
--- a/src/osmo-bsc/bts.c
+++ b/src/osmo-bsc/bts.c
@@ -978,21 +978,30 @@
return 0;
 }

+/* Send the given C0 power reduction value to the BTS */
+int gsm_bts_send_c0_power_red(const struct gsm_bts *bts, const uint8_t red)
+{
+   if (!osmo_bts_has_feature(>features, BTS_FEAT_BCCH_POWER_RED))
+   return -ENOTSUP;
+   if (bts->model->power_ctrl_send_c0_power_red == NULL)
+   return -ENOTSUP;
+   return bts->model->power_ctrl_send_c0_power_red(bts, red);
+}
+
+/* Send the given C0 power reduction value to the BTS and update the internal 
state */
 int gsm_bts_set_c0_power_red(struct gsm_bts *bts, const uint8_t red)
 {
struct gsm_bts_trx *c0 = bts->c0;
unsigned int tn;
int rc;

-   if (!osmo_bts_has_feature(>features, BTS_FEAT_BCCH_POWER_RED))
-   return -ENOTSUP;
-   if (bts->model->power_ctrl_send_c0_power_red == NULL)
-   return -ENOTSUP;
-
-   rc = bts->model->power_ctrl_send_c0_power_red(bts, red);
+   rc = gsm_bts_send_c0_power_red(bts, red);
if (rc != 0)
return rc;

+   LOG_BTS(bts, DRSL, LOGL_NOTICE, "%sabling BCCH carrier power reduction "
+   "operation mode (maximum %u dB)\n", red ? "En" : "Dis", red);
+
/* Timeslot 0 is always transmitting BCCH/CCCH */
c0->ts[0].c0_max_power_red_db = 0;

diff --git a/src/osmo-bsc/bts_osmobts.c b/src/osmo-bsc/bts_osmobts.c
index 5f6f86f..ea0405b 100644
--- a/src/osmo-bsc/bts_osmobts.c
+++ b/src/osmo-bsc/bts_osmobts.c
@@ -168,10 +168,6 @@
if (msg == NULL)
return -ENOMEM;

-   LOGP(DRSL, LOGL_NOTICE, "%sabling BCCH carrier power reduction "
-"operation mode for BTS%u (maximum %u dB)\n",
-red ? "En" : "Dis", bts->nr, red);
-
/* Abuse the standard BS POWER CONTROL message by specifying 'Common 
Channel'
 * in the Protocol Discriminator field and 'BCCH' in the Channel Number 
IE. */
dh = (struct abis_rsl_dchan_hdr *) msgb_put(msg, sizeof(*dh));
diff --git a/src/osmo-bsc/nm_bts_fsm.c b/src/osmo-bsc/nm_bts_fsm.c
index 92728dc..ea9fa5c 100644
--- a/src/osmo-bsc/nm_bts_fsm.c
+++ b/src/osmo-bsc/nm_bts_fsm.c
@@ -286,6 +286,13 @@
bts->mo.get_attr_rep_received = false;
bts->mo.set_attr_sent = false;
bts->mo.set_attr_ack_received = false;
+
+   /* Resume power saving on the BCCH carrier, if was enabled */
+   if (bts->c0_max_power_red_db > 0) {
+   LOG_BTS(bts, DRSL, LOGL_NOTICE, "Resuming BCCH carrier power 
reduction "
+   "operation mode (maximum %u dB)\n", 
bts->c0_max_power_red_db);
+   gsm_bts_send_c0_power_red(bts, bts->c0_max_power_red_db);
+   }
 }

 static void st_op_enabled(struct osmo_fsm_inst *fi, uint32_t event, void *data)

--
To view, visit https://gerrit.osmocom.org/c/osmo-bsc/+/32540
To unsubscribe, or for help writing mail filters, visit 
https://gerrit.osmocom.org/settings

Gerrit-Project: osmo-bsc
Gerrit-Branch: master
Gerrit-Change-Id: Ic3f8a2ab0ffd049a8ed84361a3a588c1e1b23ac6
Gerrit-Change-Number: 32540
Gerrit-PatchSet: 2
Gerrit-Owner: fixeria 
Gerrit-Reviewer: Jenkins Builder
Gerrit-Reviewer: 

[S] Change in osmo-bsc[master]: bootstrap_rsl(): cosmetic: cache trx->bts and use it directly

2023-04-29 Thread fixeria
fixeria has submitted this change. ( 
https://gerrit.osmocom.org/c/osmo-bsc/+/32539 )

Change subject: bootstrap_rsl(): cosmetic: cache trx->bts and use it directly
..

bootstrap_rsl(): cosmetic: cache trx->bts and use it directly

Change-Id: I736ebf185028976dad5ff6f61386b6d2eeab8fbd
Related: SYS#6435
---
M src/osmo-bsc/osmo_bsc_main.c
1 file changed, 17 insertions(+), 7 deletions(-)

Approvals:
  Jenkins Builder: Verified
  pespin: Looks good to me, approved
  laforge: Looks good to me, approved




diff --git a/src/osmo-bsc/osmo_bsc_main.c b/src/osmo-bsc/osmo_bsc_main.c
index 50cc0e0..133e5c2 100644
--- a/src/osmo-bsc/osmo_bsc_main.c
+++ b/src/osmo-bsc/osmo_bsc_main.c
@@ -312,16 +312,16 @@

 static void bootstrap_rsl(struct gsm_bts_trx *trx)
 {
+   struct gsm_bts *bts = trx->bts;
unsigned int i;
int rc;

LOG_TRX(trx, DRSL, LOGL_NOTICE, "bootstrapping RSL "
"on ARFCN %u using MCC-MNC %s LAC=%u CID=%u BSIC=%u\n",
trx->arfcn, osmo_plmn_name(_gsmnet->plmn),
-   trx->bts->location_area_code,
-   trx->bts->cell_identity, trx->bts->bsic);
+   bts->location_area_code, bts->cell_identity, bts->bsic);

-   if (trx->bts->type == GSM_BTS_TYPE_NOKIA_SITE) {
+   if (bts->type == GSM_BTS_TYPE_NOKIA_SITE) {
rsl_nokia_si_begin(trx);
}
 
@@ -338,14 +338,14 @@
return;
}

-   if (trx->bts->type == GSM_BTS_TYPE_NOKIA_SITE) {
+   if (bts->type == GSM_BTS_TYPE_NOKIA_SITE) {
/* channel unspecific, power reduction in 2 dB steps */
rsl_bs_power_control(trx, 0xFF, trx->max_power_red / 2);
rsl_nokia_si_end(trx);
}

-   if (trx->bts->model->power_ctrl_send_def_params != NULL) {
-   rc = trx->bts->model->power_ctrl_send_def_params(trx);
+   if (bts->model->power_ctrl_send_def_params != NULL) {
+   rc = bts->model->power_ctrl_send_def_params(trx);
if (rc) {
LOG_TRX(trx, DRSL, LOGL_ERROR, "Failed to send default "
"MS/BS Power control parameters (rc=%d)\n", rc);
@@ -360,7 +360,7 @@
}

/* Drop all expired channel requests in the list */
-   abis_rsl_chan_rqd_queue_flush(trx->bts);
+   abis_rsl_chan_rqd_queue_flush(bts);
 }

 struct osmo_timer_list update_connection_stats_timer;

--
To view, visit https://gerrit.osmocom.org/c/osmo-bsc/+/32539
To unsubscribe, or for help writing mail filters, visit 
https://gerrit.osmocom.org/settings

Gerrit-Project: osmo-bsc
Gerrit-Branch: master
Gerrit-Change-Id: I736ebf185028976dad5ff6f61386b6d2eeab8fbd
Gerrit-Change-Number: 32539
Gerrit-PatchSet: 1
Gerrit-Owner: fixeria 
Gerrit-Reviewer: Jenkins Builder
Gerrit-Reviewer: fixeria 
Gerrit-Reviewer: laforge 
Gerrit-Reviewer: pespin 
Gerrit-MessageType: merged


[S] Change in osmo-bsc[master]: struct gsm_bts_model: rename power_ctrl_{set->send}_c0_power_red

2023-04-29 Thread fixeria
fixeria has submitted this change. ( 
https://gerrit.osmocom.org/c/osmo-bsc/+/32538 )

Change subject: struct gsm_bts_model: rename power_ctrl_{set->send}_c0_power_red
..

struct gsm_bts_model: rename power_ctrl_{set->send}_c0_power_red

Change-Id: I13d9e6ea2a2b7b11f92532d377e71f0e83974622
Related: SYS#6435
---
M include/osmocom/bsc/bts.h
M src/osmo-bsc/bts.c
M src/osmo-bsc/bts_osmobts.c
3 files changed, 15 insertions(+), 6 deletions(-)

Approvals:
  Jenkins Builder: Verified
  pespin: Looks good to me, but someone else must approve
  laforge: Looks good to me, approved




diff --git a/include/osmocom/bsc/bts.h b/include/osmocom/bsc/bts.h
index 20ed089..9b2aaab 100644
--- a/include/osmocom/bsc/bts.h
+++ b/include/osmocom/bsc/bts.h
@@ -300,7 +300,7 @@
/* (Optional) function for sending default MS/BS Power Control 
paramaters */
int (*power_ctrl_send_def_params)(const struct gsm_bts_trx *trx);
/* (Optional) function for toggling BCCH carrier power reduction 
operation */
-   int (*power_ctrl_set_c0_power_red)(const struct gsm_bts *bts, const 
uint8_t red);
+   int (*power_ctrl_send_c0_power_red)(const struct gsm_bts *bts, const 
uint8_t red);

void (*config_write_bts)(struct vty *vty, struct gsm_bts *bts);
void (*config_write_trx)(struct vty *vty, struct gsm_bts_trx *trx);
diff --git a/src/osmo-bsc/bts.c b/src/osmo-bsc/bts.c
index 527220f..f5936c7 100644
--- a/src/osmo-bsc/bts.c
+++ b/src/osmo-bsc/bts.c
@@ -986,10 +986,10 @@

if (!osmo_bts_has_feature(>features, BTS_FEAT_BCCH_POWER_RED))
return -ENOTSUP;
-   if (bts->model->power_ctrl_set_c0_power_red == NULL)
+   if (bts->model->power_ctrl_send_c0_power_red == NULL)
return -ENOTSUP;

-   rc = bts->model->power_ctrl_set_c0_power_red(bts, red);
+   rc = bts->model->power_ctrl_send_c0_power_red(bts, red);
if (rc != 0)
return rc;

diff --git a/src/osmo-bsc/bts_osmobts.c b/src/osmo-bsc/bts_osmobts.c
index 078cfe7..5f6f86f 100644
--- a/src/osmo-bsc/bts_osmobts.c
+++ b/src/osmo-bsc/bts_osmobts.c
@@ -159,8 +159,7 @@
*ie_len = msg->tail - (ie_len + 1);
 }

-static int power_ctrl_set_c0_power_red(const struct gsm_bts *bts,
-  const uint8_t red)
+static int power_ctrl_send_c0_power_red(const struct gsm_bts *bts, const 
uint8_t red)
 {
struct abis_rsl_dchan_hdr *dh;
struct msgb *msg;
@@ -198,7 +197,7 @@
model_osmobts.force_combined_si = false;

/* Power control API */
-   model_osmobts.power_ctrl_set_c0_power_red = 
_ctrl_set_c0_power_red;
+   model_osmobts.power_ctrl_send_c0_power_red = 
_ctrl_send_c0_power_red;

model_osmobts.features.data = _osmobts._features_data[0];
model_osmobts.features.data_len =

--
To view, visit https://gerrit.osmocom.org/c/osmo-bsc/+/32538
To unsubscribe, or for help writing mail filters, visit 
https://gerrit.osmocom.org/settings

Gerrit-Project: osmo-bsc
Gerrit-Branch: master
Gerrit-Change-Id: I13d9e6ea2a2b7b11f92532d377e71f0e83974622
Gerrit-Change-Number: 32538
Gerrit-PatchSet: 1
Gerrit-Owner: fixeria 
Gerrit-Reviewer: Jenkins Builder
Gerrit-Reviewer: fixeria 
Gerrit-Reviewer: laforge 
Gerrit-Reviewer: pespin 
Gerrit-MessageType: merged


[S] Change in osmo-bsc[master]: bts_is_online(): make the BTS pointer const, return bool

2023-04-29 Thread fixeria
fixeria has submitted this change. ( 
https://gerrit.osmocom.org/c/osmo-bsc/+/32537 )

Change subject: bts_is_online(): make the BTS pointer const, return bool
..

bts_is_online(): make the BTS pointer const, return bool

Change-Id: Idb4f9f8862041c5902df0e6e8d1ac2a60ada95df
---
M src/osmo-bsc/bts.c
1 file changed, 12 insertions(+), 3 deletions(-)

Approvals:
  Jenkins Builder: Verified
  pespin: Looks good to me, but someone else must approve
  laforge: Looks good to me, approved




diff --git a/src/osmo-bsc/bts.c b/src/osmo-bsc/bts.c
index 108c355..527220f 100644
--- a/src/osmo-bsc/bts.c
+++ b/src/osmo-bsc/bts.c
@@ -888,14 +888,14 @@
return (base->depends_on[idx] & (1U << bit)) > 0;
 }

-static int bts_is_online(struct gsm_bts *bts)
+static bool bts_is_online(const struct gsm_bts *bts)
 {
/* TODO: support E1 BTS too */
if (!is_ipaccess_bts(bts))
-   return 1;
+   return true;

if (!bts->oml_link)
-   return 0;
+   return false;

return bts->mo.nm_state.operational == NM_OPSTATE_ENABLED;
 }

--
To view, visit https://gerrit.osmocom.org/c/osmo-bsc/+/32537
To unsubscribe, or for help writing mail filters, visit 
https://gerrit.osmocom.org/settings

Gerrit-Project: osmo-bsc
Gerrit-Branch: master
Gerrit-Change-Id: Idb4f9f8862041c5902df0e6e8d1ac2a60ada95df
Gerrit-Change-Number: 32537
Gerrit-PatchSet: 1
Gerrit-Owner: fixeria 
Gerrit-Reviewer: Jenkins Builder
Gerrit-Reviewer: fixeria 
Gerrit-Reviewer: laforge 
Gerrit-Reviewer: pespin 
Gerrit-MessageType: merged


[M] Change in osmo-bsc[master]: ctrl: Add getting access control class

2023-04-29 Thread matanp
Attention is currently required from: laforge, daniel.

matanp has posted comments on this change. ( 
https://gerrit.osmocom.org/c/osmo-bsc/+/32519 )

Change subject: ctrl: Add getting access control class
..


Patch Set 3:

(1 comment)

Patchset:

PS3:
> I'm not sure if we have a policy to only have one parameter in a given CTRL 
> string? Maybe something  […]
It is not exactly the same, but in my opinion "rf_states", "channel-load" and 
"neighbor-bts list" kind of return more than one parameter. I agree that it is 
less common and separation character changes (spaces in "channel-load", commas 
in "neighbor-bts list" and semicolons in "rf_states")



--
To view, visit https://gerrit.osmocom.org/c/osmo-bsc/+/32519
To unsubscribe, or for help writing mail filters, visit 
https://gerrit.osmocom.org/settings

Gerrit-Project: osmo-bsc
Gerrit-Branch: master
Gerrit-Change-Id: I279249f9047f5edacc9edf3d231e3e74023fc84e
Gerrit-Change-Number: 32519
Gerrit-PatchSet: 3
Gerrit-Owner: matanp 
Gerrit-Reviewer: Jenkins Builder
Gerrit-Reviewer: daniel 
Gerrit-CC: laforge 
Gerrit-Attention: laforge 
Gerrit-Attention: daniel 
Gerrit-Comment-Date: Sun, 30 Apr 2023 04:26:07 +
Gerrit-HasComments: Yes
Gerrit-Has-Labels: No
Comment-In-Reply-To: laforge 
Gerrit-MessageType: comment


[M] Change in osmo-hlr[master]: hlr: use talloc for memory allocation in osmo_gsup_create_insert_subs...

2023-04-29 Thread laforge
Attention is currently required from: pespin, lynxis lazus.

laforge has posted comments on this change. ( 
https://gerrit.osmocom.org/c/osmo-hlr/+/32511 )

Change subject: hlr: use talloc for memory allocation in 
osmo_gsup_create_insert_subscriber_data_msg
..


Patch Set 3:

(1 comment)

File include/osmocom/hlr/gsup_server.h:

https://gerrit.osmocom.org/c/osmo-hlr/+/32511/comment/381b7d69_43470357
PS3, Line 71: osmo_gsup_create_insert_subscriber_data_msg
this looks like a public API function of libosmo-gsup to me?  In that case, we 
cannot simply break ABI and API.  We must introduce another function for the 
new behavior, keeping the old one for backwards compatibiliy.



--
To view, visit https://gerrit.osmocom.org/c/osmo-hlr/+/32511
To unsubscribe, or for help writing mail filters, visit 
https://gerrit.osmocom.org/settings

Gerrit-Project: osmo-hlr
Gerrit-Branch: master
Gerrit-Change-Id: I00b5c2dfadcf6e0740e93b4c3292d2654d22e80c
Gerrit-Change-Number: 32511
Gerrit-PatchSet: 3
Gerrit-Owner: lynxis lazus 
Gerrit-Reviewer: Jenkins Builder
Gerrit-CC: laforge 
Gerrit-CC: msuraev 
Gerrit-CC: pespin 
Gerrit-Attention: pespin 
Gerrit-Attention: lynxis lazus 
Gerrit-Comment-Date: Sun, 30 Apr 2023 00:58:30 +
Gerrit-HasComments: Yes
Gerrit-Has-Labels: No
Gerrit-MessageType: comment


[S] Change in ...osmo_dia2gsup[master]: Use GSUP APN as Service-Selection field

2023-04-29 Thread laforge
Attention is currently required from: lynxis lazus.

laforge has posted comments on this change. ( 
https://gerrit.osmocom.org/c/erlang/osmo_dia2gsup/+/32514 )

Change subject: Use GSUP APN as Service-Selection field
..


Patch Set 2: Code-Review+2


--
To view, visit https://gerrit.osmocom.org/c/erlang/osmo_dia2gsup/+/32514
To unsubscribe, or for help writing mail filters, visit 
https://gerrit.osmocom.org/settings

Gerrit-Project: erlang/osmo_dia2gsup
Gerrit-Branch: master
Gerrit-Change-Id: I2a0af5d785ce62968f6e3952602d92cb4f37e4ab
Gerrit-Change-Number: 32514
Gerrit-PatchSet: 2
Gerrit-Owner: lynxis lazus 
Gerrit-Reviewer: Jenkins Builder
Gerrit-Reviewer: laforge 
Gerrit-Reviewer: pespin 
Gerrit-Attention: lynxis lazus 
Gerrit-Comment-Date: Sun, 30 Apr 2023 00:57:21 +
Gerrit-HasComments: No
Gerrit-Has-Labels: Yes
Gerrit-MessageType: comment


[M] Change in osmo-mgw[master]: mgcp_codec: move mgcp_codec_decide down

2023-04-29 Thread laforge
Attention is currently required from: dexter.

laforge has posted comments on this change. ( 
https://gerrit.osmocom.org/c/osmo-mgw/+/32506 )

Change subject: mgcp_codec: move mgcp_codec_decide down
..


Patch Set 1: Code-Review+2


--
To view, visit https://gerrit.osmocom.org/c/osmo-mgw/+/32506
To unsubscribe, or for help writing mail filters, visit 
https://gerrit.osmocom.org/settings

Gerrit-Project: osmo-mgw
Gerrit-Branch: master
Gerrit-Change-Id: I2f2538ff912eae4d80d3b74b766e18c4da94d6b6
Gerrit-Change-Number: 32506
Gerrit-PatchSet: 1
Gerrit-Owner: dexter 
Gerrit-Reviewer: Jenkins Builder
Gerrit-Reviewer: laforge 
Gerrit-Reviewer: msuraev 
Gerrit-Reviewer: pespin 
Gerrit-Attention: dexter 
Gerrit-Comment-Date: Sun, 30 Apr 2023 00:55:27 +
Gerrit-HasComments: No
Gerrit-Has-Labels: Yes
Gerrit-MessageType: comment


[S] Change in osmo-hnbgw[master]: less code dup in mem free of hnbgw_rx_ue_register_req()

2023-04-29 Thread laforge
Attention is currently required from: neels.

laforge has posted comments on this change. ( 
https://gerrit.osmocom.org/c/osmo-hnbgw/+/32528 )

Change subject: less code dup in mem free of hnbgw_rx_ue_register_req()
..


Patch Set 1: Code-Review+2


--
To view, visit https://gerrit.osmocom.org/c/osmo-hnbgw/+/32528
To unsubscribe, or for help writing mail filters, visit 
https://gerrit.osmocom.org/settings

Gerrit-Project: osmo-hnbgw
Gerrit-Branch: master
Gerrit-Change-Id: I433127f90bf6f82baf33c516f327f84d081ad69c
Gerrit-Change-Number: 32528
Gerrit-PatchSet: 1
Gerrit-Owner: neels 
Gerrit-Reviewer: Jenkins Builder
Gerrit-Reviewer: laforge 
Gerrit-Reviewer: pespin 
Gerrit-Attention: neels 
Gerrit-Comment-Date: Sun, 30 Apr 2023 00:55:11 +
Gerrit-HasComments: No
Gerrit-Has-Labels: Yes
Gerrit-MessageType: comment


[S] Change in osmo-hnbgw[master]: fix log msg typo 'Unsupportedccept'

2023-04-29 Thread laforge
Attention is currently required from: neels.

laforge has posted comments on this change. ( 
https://gerrit.osmocom.org/c/osmo-hnbgw/+/32529 )

Change subject: fix log msg typo 'Unsupportedccept'
..


Patch Set 1: Code-Review+2


--
To view, visit https://gerrit.osmocom.org/c/osmo-hnbgw/+/32529
To unsubscribe, or for help writing mail filters, visit 
https://gerrit.osmocom.org/settings

Gerrit-Project: osmo-hnbgw
Gerrit-Branch: master
Gerrit-Change-Id: I8e334ec84809b69bfff36f95adf21f6e6ae041e1
Gerrit-Change-Number: 32529
Gerrit-PatchSet: 1
Gerrit-Owner: neels 
Gerrit-Reviewer: Jenkins Builder
Gerrit-Reviewer: laforge 
Gerrit-Reviewer: msuraev 
Gerrit-Reviewer: pespin 
Gerrit-Attention: neels 
Gerrit-Comment-Date: Sun, 30 Apr 2023 00:55:00 +
Gerrit-HasComments: No
Gerrit-Has-Labels: Yes
Gerrit-MessageType: comment


[S] Change in libosmo-abis[master]: e1d: fix logic to detect if a timeslot is in use

2023-04-29 Thread laforge
Attention is currently required from: msuraev, dexter.

laforge has posted comments on this change. ( 
https://gerrit.osmocom.org/c/libosmo-abis/+/32402 )

Change subject: e1d: fix logic to detect if a timeslot is in use
..


Patch Set 5: Code-Review+2

(1 comment)

Patchset:

PS5:
> Out of curiosity, is there scenario where we would actually use stdin in here?
the scenario, as discussed elsewhere, is a process calling close(stdin) and 
then 0 getting re-used for another fd (next open/socket/...).



--
To view, visit https://gerrit.osmocom.org/c/libosmo-abis/+/32402
To unsubscribe, or for help writing mail filters, visit 
https://gerrit.osmocom.org/settings

Gerrit-Project: libosmo-abis
Gerrit-Branch: master
Gerrit-Change-Id: I67bc5ca25620ff96441391798f761144570c8306
Gerrit-Change-Number: 32402
Gerrit-PatchSet: 5
Gerrit-Owner: dexter 
Gerrit-Reviewer: Jenkins Builder
Gerrit-Reviewer: laforge 
Gerrit-Reviewer: msuraev 
Gerrit-Reviewer: pespin 
Gerrit-Attention: msuraev 
Gerrit-Attention: dexter 
Gerrit-Comment-Date: Sun, 30 Apr 2023 00:53:28 +
Gerrit-HasComments: Yes
Gerrit-Has-Labels: Yes
Comment-In-Reply-To: msuraev 
Gerrit-MessageType: comment


[S] Change in libosmo-abis[master]: e1d: initialize file descriptor numbers to -1 on startup

2023-04-29 Thread laforge
Attention is currently required from: dexter.

laforge has posted comments on this change. ( 
https://gerrit.osmocom.org/c/libosmo-abis/+/32401 )

Change subject: e1d: initialize file descriptor numbers to -1 on startup
..


Patch Set 5: Code-Review+2


--
To view, visit https://gerrit.osmocom.org/c/libosmo-abis/+/32401
To unsubscribe, or for help writing mail filters, visit 
https://gerrit.osmocom.org/settings

Gerrit-Project: libosmo-abis
Gerrit-Branch: master
Gerrit-Change-Id: I2de8fccad56279748ed9cc035aebf4e2d3935172
Gerrit-Change-Number: 32401
Gerrit-PatchSet: 5
Gerrit-Owner: dexter 
Gerrit-Reviewer: Jenkins Builder
Gerrit-Reviewer: laforge 
Gerrit-Reviewer: msuraev 
Gerrit-Reviewer: pespin 
Gerrit-Attention: dexter 
Gerrit-Comment-Date: Sun, 30 Apr 2023 00:52:17 +
Gerrit-HasComments: No
Gerrit-Has-Labels: Yes
Gerrit-MessageType: comment


[S] Change in libosmo-abis[master]: e1_input: add new driver callback function: line_create

2023-04-29 Thread laforge
Attention is currently required from: dexter.

laforge has posted comments on this change. ( 
https://gerrit.osmocom.org/c/libosmo-abis/+/32400 )

Change subject: e1_input: add new driver callback function: line_create
..


Patch Set 4: Code-Review+2


--
To view, visit https://gerrit.osmocom.org/c/libosmo-abis/+/32400
To unsubscribe, or for help writing mail filters, visit 
https://gerrit.osmocom.org/settings

Gerrit-Project: libosmo-abis
Gerrit-Branch: master
Gerrit-Change-Id: I404fa23e9b8a952be84e9716889c0dbbbc665d22
Gerrit-Change-Number: 32400
Gerrit-PatchSet: 4
Gerrit-Owner: dexter 
Gerrit-Reviewer: Jenkins Builder
Gerrit-Reviewer: laforge 
Gerrit-Reviewer: pespin 
Gerrit-CC: msuraev 
Gerrit-Attention: dexter 
Gerrit-Comment-Date: Sun, 30 Apr 2023 00:51:57 +
Gerrit-HasComments: No
Gerrit-Has-Labels: Yes
Gerrit-MessageType: comment


[S] Change in libosmo-abis[master]: e1d: do not set fd number to 0 after close

2023-04-29 Thread laforge
Attention is currently required from: tnt, dexter.

laforge has posted comments on this change. ( 
https://gerrit.osmocom.org/c/libosmo-abis/+/32392 )

Change subject: e1d: do not set fd number to 0 after close
..


Patch Set 2: Code-Review+2


--
To view, visit https://gerrit.osmocom.org/c/libosmo-abis/+/32392
To unsubscribe, or for help writing mail filters, visit 
https://gerrit.osmocom.org/settings

Gerrit-Project: libosmo-abis
Gerrit-Branch: master
Gerrit-Change-Id: I72e4775135caf4e3727c4f0654a545478c73bb83
Gerrit-Change-Number: 32392
Gerrit-PatchSet: 2
Gerrit-Owner: dexter 
Gerrit-Reviewer: Jenkins Builder
Gerrit-Reviewer: laforge 
Gerrit-Reviewer: pespin 
Gerrit-Reviewer: tnt 
Gerrit-Attention: tnt 
Gerrit-Attention: dexter 
Gerrit-Comment-Date: Sun, 30 Apr 2023 00:51:25 +
Gerrit-HasComments: No
Gerrit-Has-Labels: Yes
Gerrit-MessageType: comment


[M] Change in osmo-ttcn3-hacks[master]: MGCP_Test: add new testcases for oa/bwe conversion

2023-04-29 Thread laforge
Attention is currently required from: msuraev, dexter.

laforge has posted comments on this change. ( 
https://gerrit.osmocom.org/c/osmo-ttcn3-hacks/+/32220 )

Change subject: MGCP_Test: add new testcases for oa/bwe conversion
..


Patch Set 6: Code-Review+2


--
To view, visit https://gerrit.osmocom.org/c/osmo-ttcn3-hacks/+/32220
To unsubscribe, or for help writing mail filters, visit 
https://gerrit.osmocom.org/settings

Gerrit-Project: osmo-ttcn3-hacks
Gerrit-Branch: master
Gerrit-Change-Id: I2b2d7ef7fb4fe3aa8665c4d4295425502451
Gerrit-Change-Number: 32220
Gerrit-PatchSet: 6
Gerrit-Owner: dexter 
Gerrit-Reviewer: Jenkins Builder
Gerrit-Reviewer: laforge 
Gerrit-Reviewer: pespin 
Gerrit-CC: msuraev 
Gerrit-Attention: msuraev 
Gerrit-Attention: dexter 
Gerrit-Comment-Date: Sun, 30 Apr 2023 00:50:37 +
Gerrit-HasComments: No
Gerrit-Has-Labels: Yes
Gerrit-MessageType: comment


[L] Change in osmo-ttcn3-hacks[master]: MGCP_Test: support multiple codecs

2023-04-29 Thread laforge
Attention is currently required from: pespin, dexter.

laforge has posted comments on this change. ( 
https://gerrit.osmocom.org/c/osmo-ttcn3-hacks/+/32153 )

Change subject: MGCP_Test: support multiple codecs
..


Patch Set 9: Code-Review+2


--
To view, visit https://gerrit.osmocom.org/c/osmo-ttcn3-hacks/+/32153
To unsubscribe, or for help writing mail filters, visit 
https://gerrit.osmocom.org/settings

Gerrit-Project: osmo-ttcn3-hacks
Gerrit-Branch: master
Gerrit-Change-Id: I8422313fccad1bfcee52c933f643068bebdaf2d5
Gerrit-Change-Number: 32153
Gerrit-PatchSet: 9
Gerrit-Owner: dexter 
Gerrit-Reviewer: Jenkins Builder
Gerrit-Reviewer: laforge 
Gerrit-Reviewer: pespin 
Gerrit-Attention: pespin 
Gerrit-Attention: dexter 
Gerrit-Comment-Date: Sun, 30 Apr 2023 00:49:18 +
Gerrit-HasComments: No
Gerrit-Has-Labels: Yes
Gerrit-MessageType: comment


[S] Change in osmo-ci[master]: jobs/gerrit: disable endianness check for osmo-ci

2023-04-29 Thread laforge
Attention is currently required from: osmith.

laforge has posted comments on this change. ( 
https://gerrit.osmocom.org/c/osmo-ci/+/32499 )

Change subject: jobs/gerrit: disable endianness check for osmo-ci
..


Patch Set 2: Code-Review+2


--
To view, visit https://gerrit.osmocom.org/c/osmo-ci/+/32499
To unsubscribe, or for help writing mail filters, visit 
https://gerrit.osmocom.org/settings

Gerrit-Project: osmo-ci
Gerrit-Branch: master
Gerrit-Change-Id: Ib9a2ed2ce02a171f0bdca56728f8cdabf8f4cd1f
Gerrit-Change-Number: 32499
Gerrit-PatchSet: 2
Gerrit-Owner: osmith 
Gerrit-Reviewer: Jenkins Builder
Gerrit-Reviewer: laforge 
Gerrit-Reviewer: msuraev 
Gerrit-Reviewer: pespin 
Gerrit-Attention: osmith 
Gerrit-Comment-Date: Sun, 30 Apr 2023 00:49:03 +
Gerrit-HasComments: No
Gerrit-Has-Labels: Yes
Gerrit-MessageType: comment


[S] Change in osmo-ci[master]: publish-manuals-for-tags: enable IU/PFCP VTY cmds

2023-04-29 Thread laforge
Attention is currently required from: osmith, neels.

laforge has posted comments on this change. ( 
https://gerrit.osmocom.org/c/osmo-ci/+/32434 )

Change subject: publish-manuals-for-tags: enable IU/PFCP VTY cmds
..


Patch Set 4: Code-Review+2


--
To view, visit https://gerrit.osmocom.org/c/osmo-ci/+/32434
To unsubscribe, or for help writing mail filters, visit 
https://gerrit.osmocom.org/settings

Gerrit-Project: osmo-ci
Gerrit-Branch: master
Gerrit-Change-Id: I9685857348e3b38f13acc1429c7a49fb9e5d92f3
Gerrit-Change-Number: 32434
Gerrit-PatchSet: 4
Gerrit-Owner: osmith 
Gerrit-Reviewer: Jenkins Builder
Gerrit-Reviewer: laforge 
Gerrit-Reviewer: neels 
Gerrit-Reviewer: pespin 
Gerrit-Attention: osmith 
Gerrit-Attention: neels 
Gerrit-Comment-Date: Sun, 30 Apr 2023 00:48:50 +
Gerrit-HasComments: No
Gerrit-Has-Labels: Yes
Gerrit-MessageType: comment


[S] Change in osmo-ci[master]: jobs/master,gerrit: build manuals with IU

2023-04-29 Thread laforge
Attention is currently required from: osmith.

laforge has posted comments on this change. ( 
https://gerrit.osmocom.org/c/osmo-ci/+/32433 )

Change subject: jobs/master,gerrit: build manuals with IU
..


Patch Set 2: Code-Review+2


--
To view, visit https://gerrit.osmocom.org/c/osmo-ci/+/32433
To unsubscribe, or for help writing mail filters, visit 
https://gerrit.osmocom.org/settings

Gerrit-Project: osmo-ci
Gerrit-Branch: master
Gerrit-Change-Id: Ib9c47796b582add90ef72376b4c0368a29d89b15
Gerrit-Change-Number: 32433
Gerrit-PatchSet: 2
Gerrit-Owner: osmith 
Gerrit-Reviewer: Jenkins Builder
Gerrit-Reviewer: laforge 
Gerrit-Reviewer: neels 
Gerrit-Reviewer: pespin 
Gerrit-Attention: osmith 
Gerrit-Comment-Date: Sun, 30 Apr 2023 00:39:49 +
Gerrit-HasComments: No
Gerrit-Has-Labels: Yes
Gerrit-MessageType: comment


[S] Change in osmo-ci[master]: jobs/master,gerrit: use PFCP var for osmo-hnbgw

2023-04-29 Thread laforge
Attention is currently required from: osmith, Max, neels.

laforge has posted comments on this change. ( 
https://gerrit.osmocom.org/c/osmo-ci/+/32432 )

Change subject: jobs/master,gerrit: use PFCP var for osmo-hnbgw
..


Patch Set 2: Code-Review+2


--
To view, visit https://gerrit.osmocom.org/c/osmo-ci/+/32432
To unsubscribe, or for help writing mail filters, visit 
https://gerrit.osmocom.org/settings

Gerrit-Project: osmo-ci
Gerrit-Branch: master
Gerrit-Change-Id: I4a4e25e0c179c0d408c3728a28eb75bbfa086f48
Gerrit-Change-Number: 32432
Gerrit-PatchSet: 2
Gerrit-Owner: osmith 
Gerrit-Reviewer: Jenkins Builder
Gerrit-Reviewer: Max 
Gerrit-Reviewer: laforge 
Gerrit-Reviewer: neels 
Gerrit-Reviewer: pespin 
Gerrit-Attention: osmith 
Gerrit-Attention: Max 
Gerrit-Attention: neels 
Gerrit-Comment-Date: Sun, 30 Apr 2023 00:39:12 +
Gerrit-HasComments: No
Gerrit-Has-Labels: Yes
Gerrit-MessageType: comment


[L] Change in osmo-hnbgw[master]: sccp: allow separate cs7 for IuPS and IuCS

2023-04-29 Thread laforge
Attention is currently required from: neels, pespin, msuraev.

laforge has posted comments on this change. ( 
https://gerrit.osmocom.org/c/osmo-hnbgw/+/32323 )

Change subject: sccp: allow separate cs7 for IuPS and IuCS
..


Patch Set 5: Code-Review+1


--
To view, visit https://gerrit.osmocom.org/c/osmo-hnbgw/+/32323
To unsubscribe, or for help writing mail filters, visit 
https://gerrit.osmocom.org/settings

Gerrit-Project: osmo-hnbgw
Gerrit-Branch: master
Gerrit-Change-Id: Iea1824f1c586723d989c80a909bae16bd2866e08
Gerrit-Change-Number: 32323
Gerrit-PatchSet: 5
Gerrit-Owner: neels 
Gerrit-Reviewer: Jenkins Builder
Gerrit-Reviewer: laforge 
Gerrit-CC: msuraev 
Gerrit-CC: pespin 
Gerrit-Attention: neels 
Gerrit-Attention: pespin 
Gerrit-Attention: msuraev 
Gerrit-Comment-Date: Sun, 30 Apr 2023 00:35:37 +
Gerrit-HasComments: No
Gerrit-Has-Labels: Yes
Gerrit-MessageType: comment


[M] Change in osmo-hnbgw[master]: charts: add sccp.dot

2023-04-29 Thread laforge
Attention is currently required from: neels.

laforge has posted comments on this change. ( 
https://gerrit.osmocom.org/c/osmo-hnbgw/+/32322 )

Change subject: charts: add sccp.dot
..


Patch Set 1: Code-Review+2


--
To view, visit https://gerrit.osmocom.org/c/osmo-hnbgw/+/32322
To unsubscribe, or for help writing mail filters, visit 
https://gerrit.osmocom.org/settings

Gerrit-Project: osmo-hnbgw
Gerrit-Branch: master
Gerrit-Change-Id: I109948758de998326a5e9f0dcdc84d5f11dfba02
Gerrit-Change-Number: 32322
Gerrit-PatchSet: 1
Gerrit-Owner: neels 
Gerrit-Reviewer: Jenkins Builder
Gerrit-Reviewer: laforge 
Gerrit-Reviewer: msuraev 
Gerrit-Attention: neels 
Gerrit-Comment-Date: Sun, 30 Apr 2023 00:31:30 +
Gerrit-HasComments: No
Gerrit-Has-Labels: Yes
Gerrit-MessageType: comment


[S] Change in libosmocore[master]: gb: ns2: Rename parameter name in gprs_ns2_nsvc_by_sockaddr_bind()

2023-04-29 Thread laforge
Attention is currently required from: pespin.

laforge has posted comments on this change. ( 
https://gerrit.osmocom.org/c/libosmocore/+/32534 )

Change subject: gb: ns2: Rename parameter name in 
gprs_ns2_nsvc_by_sockaddr_bind()
..


Patch Set 2: Code-Review+2


--
To view, visit https://gerrit.osmocom.org/c/libosmocore/+/32534
To unsubscribe, or for help writing mail filters, visit 
https://gerrit.osmocom.org/settings

Gerrit-Project: libosmocore
Gerrit-Branch: master
Gerrit-Change-Id: I3f45a4ef339cadd47920ee3b36c38628b38221f6
Gerrit-Change-Number: 32534
Gerrit-PatchSet: 2
Gerrit-Owner: pespin 
Gerrit-Reviewer: Jenkins Builder
Gerrit-Reviewer: fixeria 
Gerrit-Reviewer: laforge 
Gerrit-Reviewer: lynxis lazus 
Gerrit-Reviewer: osmith 
Gerrit-Attention: pespin 
Gerrit-Comment-Date: Sun, 30 Apr 2023 00:31:09 +
Gerrit-HasComments: No
Gerrit-Has-Labels: Yes
Gerrit-MessageType: comment


[M] Change in osmo-bsc[master]: ctrl: Add setting access control class

2023-04-29 Thread laforge
Attention is currently required from: matanp.

laforge has posted comments on this change. ( 
https://gerrit.osmocom.org/c/osmo-bsc/+/32520 )

Change subject: ctrl: Add setting access control class
..


Patch Set 3: Code-Review+1


--
To view, visit https://gerrit.osmocom.org/c/osmo-bsc/+/32520
To unsubscribe, or for help writing mail filters, visit 
https://gerrit.osmocom.org/settings

Gerrit-Project: osmo-bsc
Gerrit-Branch: master
Gerrit-Change-Id: I7abbf0adc3798e9224834a68d7cdce4bbe03c9a3
Gerrit-Change-Number: 32520
Gerrit-PatchSet: 3
Gerrit-Owner: matanp 
Gerrit-Reviewer: Jenkins Builder
Gerrit-Reviewer: laforge 
Gerrit-Attention: matanp 
Gerrit-Comment-Date: Sun, 30 Apr 2023 00:27:49 +
Gerrit-HasComments: No
Gerrit-Has-Labels: Yes
Gerrit-MessageType: comment


[M] Change in osmo-bsc[master]: ctrl: Add getting access control class

2023-04-29 Thread laforge
Attention is currently required from: daniel, matanp.

laforge has posted comments on this change. ( 
https://gerrit.osmocom.org/c/osmo-bsc/+/32519 )

Change subject: ctrl: Add getting access control class
..


Patch Set 3:

(1 comment)

Patchset:

PS3:
I'm not sure if we have a policy to only have one parameter in a given CTRL 
string? Maybe something for daniel to comment on...



--
To view, visit https://gerrit.osmocom.org/c/osmo-bsc/+/32519
To unsubscribe, or for help writing mail filters, visit 
https://gerrit.osmocom.org/settings

Gerrit-Project: osmo-bsc
Gerrit-Branch: master
Gerrit-Change-Id: I279249f9047f5edacc9edf3d231e3e74023fc84e
Gerrit-Change-Number: 32519
Gerrit-PatchSet: 3
Gerrit-Owner: matanp 
Gerrit-Reviewer: Jenkins Builder
Gerrit-Reviewer: daniel 
Gerrit-CC: laforge 
Gerrit-Attention: daniel 
Gerrit-Attention: matanp 
Gerrit-Comment-Date: Sun, 30 Apr 2023 00:27:26 +
Gerrit-HasComments: Yes
Gerrit-Has-Labels: No
Gerrit-MessageType: comment


[S] Change in osmo-bsc[master]: ctrl: Add cell reselection hysteresis control

2023-04-29 Thread laforge
Attention is currently required from: pespin, matanp.

laforge has posted comments on this change. ( 
https://gerrit.osmocom.org/c/osmo-bsc/+/32515 )

Change subject: ctrl: Add cell reselection hysteresis control
..


Patch Set 2: Code-Review+1


--
To view, visit https://gerrit.osmocom.org/c/osmo-bsc/+/32515
To unsubscribe, or for help writing mail filters, visit 
https://gerrit.osmocom.org/settings

Gerrit-Project: osmo-bsc
Gerrit-Branch: master
Gerrit-Change-Id: Ia96f6656d99381c039a4b3fd02674215fbbaec91
Gerrit-Change-Number: 32515
Gerrit-PatchSet: 2
Gerrit-Owner: matanp 
Gerrit-Reviewer: Jenkins Builder
Gerrit-Reviewer: laforge 
Gerrit-CC: pespin 
Gerrit-Attention: pespin 
Gerrit-Attention: matanp 
Gerrit-Comment-Date: Sun, 30 Apr 2023 00:26:22 +
Gerrit-HasComments: No
Gerrit-Has-Labels: Yes
Gerrit-MessageType: comment


[M] Change in osmo-bsc[master]: ctrl: Add penalty time control

2023-04-29 Thread laforge
Attention is currently required from: pespin, matanp, dexter.

laforge has posted comments on this change. ( 
https://gerrit.osmocom.org/c/osmo-bsc/+/32498 )

Change subject: ctrl: Add penalty time control
..


Patch Set 5: Code-Review+1


--
To view, visit https://gerrit.osmocom.org/c/osmo-bsc/+/32498
To unsubscribe, or for help writing mail filters, visit 
https://gerrit.osmocom.org/settings

Gerrit-Project: osmo-bsc
Gerrit-Branch: master
Gerrit-Change-Id: Idfdd54dec72fb5f52eee22df018161d75b8c48c8
Gerrit-Change-Number: 32498
Gerrit-PatchSet: 5
Gerrit-Owner: matanp 
Gerrit-Reviewer: Jenkins Builder
Gerrit-Reviewer: laforge 
Gerrit-Reviewer: pespin 
Gerrit-CC: dexter 
Gerrit-Attention: pespin 
Gerrit-Attention: matanp 
Gerrit-Attention: dexter 
Gerrit-Comment-Date: Sun, 30 Apr 2023 00:25:52 +
Gerrit-HasComments: No
Gerrit-Has-Labels: Yes
Gerrit-MessageType: comment


[XL] Change in libosmocore[master]: Add osmo_io with initial poll backend

2023-04-29 Thread laforge
Attention is currently required from: osmith, Hoernchen, neels, pespin, 
fixeria, daniel.

laforge has posted comments on this change. ( 
https://gerrit.osmocom.org/c/libosmocore/+/30934 )

Change subject: Add osmo_io with initial poll backend
..


Patch Set 12: Code-Review+1

(1 comment)

File src/core/osmo_io.c:

https://gerrit.osmocom.org/c/libosmocore/+/30934/comment/4a133366_4b240bd6
PS12, Line 71: LIBOSMO_IO_BACKEND
I guess this environment variable would need to be documented somewhere.

At least in doxygen for now (developer documentation), but for sure once we add 
support for other backends also in some common chapter of the 
osmo-gsm-manuals.git (user documentation)



--
To view, visit https://gerrit.osmocom.org/c/libosmocore/+/30934
To unsubscribe, or for help writing mail filters, visit 
https://gerrit.osmocom.org/settings

Gerrit-Project: libosmocore
Gerrit-Branch: master
Gerrit-Change-Id: I50d73cf550d6ce8154bf827bf47408131cf5b0a0
Gerrit-Change-Number: 30934
Gerrit-PatchSet: 12
Gerrit-Owner: daniel 
Gerrit-Reviewer: Hoernchen 
Gerrit-Reviewer: Jenkins Builder
Gerrit-Reviewer: fixeria 
Gerrit-Reviewer: laforge 
Gerrit-Reviewer: neels 
Gerrit-Reviewer: osmith 
Gerrit-Reviewer: pespin 
Gerrit-Attention: osmith 
Gerrit-Attention: Hoernchen 
Gerrit-Attention: neels 
Gerrit-Attention: pespin 
Gerrit-Attention: fixeria 
Gerrit-Attention: daniel 
Gerrit-Comment-Date: Sun, 30 Apr 2023 00:21:05 +
Gerrit-HasComments: Yes
Gerrit-Has-Labels: Yes
Gerrit-MessageType: comment


[M] Change in libosmocore[master]: ns2: Count transmitted/dropped in each layer implementation

2023-04-29 Thread laforge
Attention is currently required from: pespin, lynxis lazus.

laforge has posted comments on this change. ( 
https://gerrit.osmocom.org/c/libosmocore/+/32535 )

Change subject: ns2: Count transmitted/dropped in each layer implementation
..


Patch Set 1: Code-Review+1


--
To view, visit https://gerrit.osmocom.org/c/libosmocore/+/32535
To unsubscribe, or for help writing mail filters, visit 
https://gerrit.osmocom.org/settings

Gerrit-Project: libosmocore
Gerrit-Branch: master
Gerrit-Change-Id: I8109cee07f157ebf1806f82a071f58de3a2dcc9c
Gerrit-Change-Number: 32535
Gerrit-PatchSet: 1
Gerrit-Owner: pespin 
Gerrit-Reviewer: Jenkins Builder
Gerrit-Reviewer: laforge 
Gerrit-Reviewer: lynxis lazus 
Gerrit-Attention: pespin 
Gerrit-Attention: lynxis lazus 
Gerrit-Comment-Date: Sun, 30 Apr 2023 00:17:58 +
Gerrit-HasComments: No
Gerrit-Has-Labels: Yes
Gerrit-MessageType: comment


[M] Change in libosmocore[master]: gpsr_ns2_udp: Use osmo_io_fd instead of osmo_fd

2023-04-29 Thread laforge
Attention is currently required from: pespin, daniel, lynxis lazus.

laforge has posted comments on this change. ( 
https://gerrit.osmocom.org/c/libosmocore/+/30936 )

Change subject: gpsr_ns2_udp: Use osmo_io_fd instead of osmo_fd
..


Patch Set 11: Code-Review+1

(1 comment)

File src/gb/gprs_ns2_udp.c:

https://gerrit.osmocom.org/c/libosmocore/+/30936/comment/d29156cc_c06bffa5
PS11, Line 226:const struct msgb *msg,
do we need to register an empty call-back function if it does nothing? 
shouldn't we simply allow registering NULL if there's nothing to be done here?



--
To view, visit https://gerrit.osmocom.org/c/libosmocore/+/30936
To unsubscribe, or for help writing mail filters, visit 
https://gerrit.osmocom.org/settings

Gerrit-Project: libosmocore
Gerrit-Branch: master
Gerrit-Change-Id: Id776d2d9f35c304620f3d5b94492148dd987f5a0
Gerrit-Change-Number: 30936
Gerrit-PatchSet: 11
Gerrit-Owner: daniel 
Gerrit-Reviewer: Jenkins Builder
Gerrit-Reviewer: laforge 
Gerrit-Reviewer: lynxis lazus 
Gerrit-CC: pespin 
Gerrit-Attention: pespin 
Gerrit-Attention: daniel 
Gerrit-Attention: lynxis lazus 
Gerrit-Comment-Date: Sun, 30 Apr 2023 00:17:22 +
Gerrit-HasComments: Yes
Gerrit-Has-Labels: Yes
Gerrit-MessageType: comment


[M] Change in libosmocore[master]: tests: Add initial osmo_io tests

2023-04-29 Thread laforge
Attention is currently required from: pespin, fixeria, daniel.

laforge has posted comments on this change. ( 
https://gerrit.osmocom.org/c/libosmocore/+/32181 )

Change subject: tests: Add initial osmo_io tests
..


Patch Set 8: Code-Review+1


--
To view, visit https://gerrit.osmocom.org/c/libosmocore/+/32181
To unsubscribe, or for help writing mail filters, visit 
https://gerrit.osmocom.org/settings

Gerrit-Project: libosmocore
Gerrit-Branch: master
Gerrit-Change-Id: Ia67629e53f4d2e5784177250d58e268fdfcaa0c2
Gerrit-Change-Number: 32181
Gerrit-PatchSet: 8
Gerrit-Owner: daniel 
Gerrit-Reviewer: Jenkins Builder
Gerrit-Reviewer: laforge 
Gerrit-CC: fixeria 
Gerrit-CC: pespin 
Gerrit-Attention: pespin 
Gerrit-Attention: fixeria 
Gerrit-Attention: daniel 
Gerrit-Comment-Date: Sun, 30 Apr 2023 00:15:51 +
Gerrit-HasComments: No
Gerrit-Has-Labels: Yes
Gerrit-MessageType: comment


[S] Change in libosmocore[master]: Fix 'Fix parsing of TLV_TYPE_SINGLE_TV'

2023-04-29 Thread laforge
Attention is currently required from: osmith, neels, pespin.

laforge has posted comments on this change. ( 
https://gerrit.osmocom.org/c/libosmocore/+/32549 )

Change subject: Fix 'Fix parsing of TLV_TYPE_SINGLE_TV'
..


Patch Set 1:

(1 comment)

Patchset:

PS1:
can we please have an associated unit test demonstrating the problem + then fix 
it?



--
To view, visit https://gerrit.osmocom.org/c/libosmocore/+/32549
To unsubscribe, or for help writing mail filters, visit 
https://gerrit.osmocom.org/settings

Gerrit-Project: libosmocore
Gerrit-Branch: master
Gerrit-Change-Id: Id619459c17976b77cd2c7e4179123bb06807285c
Gerrit-Change-Number: 32549
Gerrit-PatchSet: 1
Gerrit-Owner: pespin 
Gerrit-Reviewer: Jenkins Builder
Gerrit-Reviewer: fixeria 
Gerrit-Reviewer: neels 
Gerrit-Reviewer: osmith 
Gerrit-CC: laforge 
Gerrit-Attention: osmith 
Gerrit-Attention: neels 
Gerrit-Attention: pespin 
Gerrit-Comment-Date: Sat, 29 Apr 2023 22:28:22 +
Gerrit-HasComments: Yes
Gerrit-Has-Labels: No
Gerrit-MessageType: comment


[L] Change in libosmo-gprs[master]: gmm: Introduce SIM_AUTH primitive to resolve authentication

2023-04-29 Thread laforge
Attention is currently required from: pespin.

laforge has posted comments on this change. ( 
https://gerrit.osmocom.org/c/libosmo-gprs/+/32550 )

Change subject: gmm: Introduce SIM_AUTH primitive to resolve authentication
..


Patch Set 3: Code-Review+1

(1 comment)

File include/osmocom/gprs/gmm/gmm_prim.h:

https://gerrit.osmocom.org/c/libosmo-gprs/+/32550/comment/b965ae5d_90f0328e
PS2, Line 151:  uint8_t sres[4]; /* result */
> I think in here I also have to provide "uint8_t key[8]" (Kc?) which is 
> calculated by the sucriber. […]
I'm not sure if we should introduce new API/primitives that can *just* deal 
with 2G AKA.  Remember that you can very well use UMTS AKA over 2G bearer (CS 
or PS).  Even if our implementation might not yet support anything beyond GSM 
AUTH, the data structures / primitives might as well be designed to handle 3G 
AKA?

Not critical, just my thoughts...



--
To view, visit https://gerrit.osmocom.org/c/libosmo-gprs/+/32550
To unsubscribe, or for help writing mail filters, visit 
https://gerrit.osmocom.org/settings

Gerrit-Project: libosmo-gprs
Gerrit-Branch: master
Gerrit-Change-Id: I5c97642baac5ed29de63ae93fc7f0ecde5edf735
Gerrit-Change-Number: 32550
Gerrit-PatchSet: 3
Gerrit-Owner: pespin 
Gerrit-Reviewer: Jenkins Builder
Gerrit-Reviewer: laforge 
Gerrit-Attention: pespin 
Gerrit-Comment-Date: Sat, 29 Apr 2023 22:27:51 +
Gerrit-HasComments: Yes
Gerrit-Has-Labels: Yes
Comment-In-Reply-To: pespin 
Gerrit-MessageType: comment


[S] Change in libosmo-gprs[master]: gmm: Increase log level of Rx msg log lines

2023-04-29 Thread laforge
Attention is currently required from: pespin.

laforge has posted comments on this change. ( 
https://gerrit.osmocom.org/c/libosmo-gprs/+/32509 )

Change subject: gmm: Increase log level of Rx msg log lines
..


Patch Set 4: Code-Review+2


--
To view, visit https://gerrit.osmocom.org/c/libosmo-gprs/+/32509
To unsubscribe, or for help writing mail filters, visit 
https://gerrit.osmocom.org/settings

Gerrit-Project: libosmo-gprs
Gerrit-Branch: master
Gerrit-Change-Id: I461d6815ec42e5f77ee5d6e4d307011c566b61f0
Gerrit-Change-Number: 32509
Gerrit-PatchSet: 4
Gerrit-Owner: pespin 
Gerrit-Reviewer: Jenkins Builder
Gerrit-Reviewer: laforge 
Gerrit-Reviewer: msuraev 
Gerrit-Reviewer: osmith 
Gerrit-Attention: pespin 
Gerrit-Comment-Date: Sat, 29 Apr 2023 22:24:36 +
Gerrit-HasComments: No
Gerrit-Has-Labels: Yes
Gerrit-MessageType: comment


[S] Change in libosmo-gprs[master]: gmm: Print IMSI and TLLI in LOGGMME macro

2023-04-29 Thread laforge
Attention is currently required from: pespin.

laforge has posted comments on this change. ( 
https://gerrit.osmocom.org/c/libosmo-gprs/+/32508 )

Change subject: gmm: Print IMSI and TLLI in LOGGMME macro
..


Patch Set 4: Code-Review+2


--
To view, visit https://gerrit.osmocom.org/c/libosmo-gprs/+/32508
To unsubscribe, or for help writing mail filters, visit 
https://gerrit.osmocom.org/settings

Gerrit-Project: libosmo-gprs
Gerrit-Branch: master
Gerrit-Change-Id: I34145eb83c1678bcf1b32ae6cbf3e4b01c717406
Gerrit-Change-Number: 32508
Gerrit-PatchSet: 4
Gerrit-Owner: pespin 
Gerrit-Reviewer: Jenkins Builder
Gerrit-Reviewer: laforge 
Gerrit-Reviewer: msuraev 
Gerrit-Reviewer: osmith 
Gerrit-Attention: pespin 
Gerrit-Comment-Date: Sat, 29 Apr 2023 22:24:19 +
Gerrit-HasComments: No
Gerrit-Has-Labels: Yes
Gerrit-MessageType: comment


[L] Change in libosmo-gprs[master]: gmm, rlcmac: Properly handle P-TMSI vs TLLI

2023-04-29 Thread laforge
Attention is currently required from: pespin, fixeria.

laforge has posted comments on this change. ( 
https://gerrit.osmocom.org/c/libosmo-gprs/+/32507 )

Change subject: gmm, rlcmac: Properly handle P-TMSI vs TLLI
..


Patch Set 3: Code-Review+1


--
To view, visit https://gerrit.osmocom.org/c/libosmo-gprs/+/32507
To unsubscribe, or for help writing mail filters, visit 
https://gerrit.osmocom.org/settings

Gerrit-Project: libosmo-gprs
Gerrit-Branch: master
Gerrit-Change-Id: I44c95b3bc973b9dfcc79daf6b529fd2826f574e8
Gerrit-Change-Number: 32507
Gerrit-PatchSet: 3
Gerrit-Owner: pespin 
Gerrit-Reviewer: Jenkins Builder
Gerrit-Reviewer: laforge 
Gerrit-Reviewer: osmith 
Gerrit-CC: fixeria 
Gerrit-Attention: pespin 
Gerrit-Attention: fixeria 
Gerrit-Comment-Date: Sat, 29 Apr 2023 22:24:04 +
Gerrit-HasComments: No
Gerrit-Has-Labels: Yes
Gerrit-MessageType: comment


[M] Change in osmocom-bb[master]: layer23: modem: Resolve auth requests coming from GMM layer

2023-04-29 Thread laforge
Attention is currently required from: pespin.

laforge has posted comments on this change. ( 
https://gerrit.osmocom.org/c/osmocom-bb/+/32551 )

Change subject: layer23: modem: Resolve auth requests coming from GMM layer
..


Patch Set 1: Code-Review+1


--
To view, visit https://gerrit.osmocom.org/c/osmocom-bb/+/32551
To unsubscribe, or for help writing mail filters, visit 
https://gerrit.osmocom.org/settings

Gerrit-Project: osmocom-bb
Gerrit-Branch: master
Gerrit-Change-Id: I75dc3fe3e4d9e23443fb778e36ca024f1bc46641
Gerrit-Change-Number: 32551
Gerrit-PatchSet: 1
Gerrit-Owner: pespin 
Gerrit-Reviewer: Jenkins Builder
Gerrit-Reviewer: laforge 
Gerrit-Attention: pespin 
Gerrit-Comment-Date: Sat, 29 Apr 2023 22:23:20 +
Gerrit-HasComments: No
Gerrit-Has-Labels: Yes
Gerrit-MessageType: comment


[M] Change in osmo-bts[master]: gsm_objclass2mo(): Change signature/set NACK cause

2023-04-29 Thread laforge
Attention is currently required from: arehbein, fixeria, pespin.

laforge has posted comments on this change. ( 
https://gerrit.osmocom.org/c/osmo-bts/+/32075 )

Change subject: gsm_objclass2mo(): Change signature/set NACK cause
..


Patch Set 8: Code-Review+1

(1 comment)

File src/common/oml.c:

https://gerrit.osmocom.org/c/osmo-bts/+/32075/comment/bf366d4e_19104a6a
PS8, Line 1107: return oml_fom_ack_nack(msg, 
NM_NACK_OBJINST_UNKN);
> NACK
isn't that what the next patch in the series is doing?  looks good to me



-- 
To view, visit https://gerrit.osmocom.org/c/osmo-bts/+/32075
To unsubscribe, or for help writing mail filters, visit 
https://gerrit.osmocom.org/settings

Gerrit-Project: osmo-bts
Gerrit-Branch: master
Gerrit-Change-Id: I37e6b23ed95260a8188910cf9754faffcba519c5
Gerrit-Change-Number: 32075
Gerrit-PatchSet: 8
Gerrit-Owner: arehbein 
Gerrit-Reviewer: Jenkins Builder
Gerrit-Reviewer: fixeria 
Gerrit-Reviewer: laforge 
Gerrit-Reviewer: pespin 
Gerrit-Attention: arehbein 
Gerrit-Attention: fixeria 
Gerrit-Attention: pespin 
Gerrit-Comment-Date: Sat, 29 Apr 2023 22:22:43 +
Gerrit-HasComments: Yes
Gerrit-Has-Labels: Yes
Comment-In-Reply-To: fixeria 
Comment-In-Reply-To: pespin 
Gerrit-MessageType: comment


[M] Change in osmo-bts[master]: gsm_objclass2obj(): Change signature/set NACK cause

2023-04-29 Thread laforge
Attention is currently required from: arehbein, fixeria.

laforge has posted comments on this change. ( 
https://gerrit.osmocom.org/c/osmo-bts/+/32354 )

Change subject: gsm_objclass2obj(): Change signature/set NACK cause
..


Patch Set 4: Code-Review+1


--
To view, visit https://gerrit.osmocom.org/c/osmo-bts/+/32354
To unsubscribe, or for help writing mail filters, visit 
https://gerrit.osmocom.org/settings

Gerrit-Project: osmo-bts
Gerrit-Branch: master
Gerrit-Change-Id: If734ea2c8cae4c1f99b02520dffa4e3862a67745
Gerrit-Change-Number: 32354
Gerrit-PatchSet: 4
Gerrit-Owner: arehbein 
Gerrit-Reviewer: Jenkins Builder
Gerrit-Reviewer: laforge 
Gerrit-Reviewer: pespin 
Gerrit-CC: fixeria 
Gerrit-Attention: arehbein 
Gerrit-Attention: fixeria 
Gerrit-Comment-Date: Sat, 29 Apr 2023 22:21:46 +
Gerrit-HasComments: No
Gerrit-Has-Labels: Yes
Gerrit-MessageType: comment


[S] Change in osmo-bts[master]: osmo-bts-trx: fix trx_ctrl_read_cb(): do not send CMDs twice

2023-04-29 Thread laforge
Attention is currently required from: fixeria, pespin.

laforge has posted comments on this change. ( 
https://gerrit.osmocom.org/c/osmo-bts/+/32552 )

Change subject: osmo-bts-trx: fix trx_ctrl_read_cb(): do not send CMDs twice
..


Patch Set 2: Code-Review+1


--
To view, visit https://gerrit.osmocom.org/c/osmo-bts/+/32552
To unsubscribe, or for help writing mail filters, visit 
https://gerrit.osmocom.org/settings

Gerrit-Project: osmo-bts
Gerrit-Branch: master
Gerrit-Change-Id: Ibdffa4644aa3a7d219452644d3e74b411734f1df
Gerrit-Change-Number: 32552
Gerrit-PatchSet: 2
Gerrit-Owner: fixeria 
Gerrit-Reviewer: Jenkins Builder
Gerrit-Reviewer: laforge 
Gerrit-CC: pespin 
Gerrit-Attention: fixeria 
Gerrit-Attention: pespin 
Gerrit-Comment-Date: Sat, 29 Apr 2023 22:20:58 +
Gerrit-HasComments: No
Gerrit-Has-Labels: Yes
Gerrit-MessageType: comment


[S] Change in osmo-bsc[master]: fix mscpool for large msc NRs

2023-04-29 Thread laforge
Attention is currently required from: neels.

laforge has posted comments on this change. ( 
https://gerrit.osmocom.org/c/osmo-bsc/+/32554 )

Change subject: fix mscpool for large msc NRs
..


Patch Set 1: Code-Review+2


--
To view, visit https://gerrit.osmocom.org/c/osmo-bsc/+/32554
To unsubscribe, or for help writing mail filters, visit 
https://gerrit.osmocom.org/settings

Gerrit-Project: osmo-bsc
Gerrit-Branch: master
Gerrit-Change-Id: I98bee022c1a78508554d2ff4a10fbce3c53f1128
Gerrit-Change-Number: 32554
Gerrit-PatchSet: 1
Gerrit-Owner: neels 
Gerrit-Reviewer: Jenkins Builder
Gerrit-Reviewer: fixeria 
Gerrit-Reviewer: laforge 
Gerrit-Attention: neels 
Gerrit-Comment-Date: Sat, 29 Apr 2023 22:19:02 +
Gerrit-HasComments: No
Gerrit-Has-Labels: Yes
Gerrit-MessageType: comment


[S] Change in osmo-bsc[master]: fix length check in abis_rsl_rx_rll()

2023-04-29 Thread laforge
Attention is currently required from: neels, msuraev.

laforge has posted comments on this change. ( 
https://gerrit.osmocom.org/c/osmo-bsc/+/32421 )

Change subject: fix length check in abis_rsl_rx_rll()
..


Patch Set 2: Code-Review+1

(1 comment)

Patchset:

PS2:
might have made sense to add an inline function, but it's just two "copies", so 
not that critical.



--
To view, visit https://gerrit.osmocom.org/c/osmo-bsc/+/32421
To unsubscribe, or for help writing mail filters, visit 
https://gerrit.osmocom.org/settings

Gerrit-Project: osmo-bsc
Gerrit-Branch: master
Gerrit-Change-Id: Ie4aee615c8c904ae8308ec0074d8bc5208137061
Gerrit-Change-Number: 32421
Gerrit-PatchSet: 2
Gerrit-Owner: neels 
Gerrit-Reviewer: Jenkins Builder
Gerrit-Reviewer: fixeria 
Gerrit-Reviewer: laforge 
Gerrit-Reviewer: pespin 
Gerrit-CC: msuraev 
Gerrit-Attention: neels 
Gerrit-Attention: msuraev 
Gerrit-Comment-Date: Sat, 29 Apr 2023 22:18:40 +
Gerrit-HasComments: Yes
Gerrit-Has-Labels: Yes
Gerrit-MessageType: comment


[S] Change in osmo-bsc[master]: gsm_bts_send_c0_power_red(): check if BTS is online first

2023-04-29 Thread laforge
Attention is currently required from: fixeria.

laforge has posted comments on this change. ( 
https://gerrit.osmocom.org/c/osmo-bsc/+/32541 )

Change subject: gsm_bts_send_c0_power_red(): check if BTS is online first
..


Patch Set 2: Code-Review+2


--
To view, visit https://gerrit.osmocom.org/c/osmo-bsc/+/32541
To unsubscribe, or for help writing mail filters, visit 
https://gerrit.osmocom.org/settings

Gerrit-Project: osmo-bsc
Gerrit-Branch: master
Gerrit-Change-Id: I080aa7ef331b76918ae48d555eea6e4290c57120
Gerrit-Change-Number: 32541
Gerrit-PatchSet: 2
Gerrit-Owner: fixeria 
Gerrit-Reviewer: Jenkins Builder
Gerrit-Reviewer: laforge 
Gerrit-Reviewer: pespin 
Gerrit-Attention: fixeria 
Gerrit-Comment-Date: Sat, 29 Apr 2023 22:17:01 +
Gerrit-HasComments: No
Gerrit-Has-Labels: Yes
Gerrit-MessageType: comment


[M] Change in osmo-bsc[master]: bts: st_op_enabled_on_enter(): resume C0 power reduction

2023-04-29 Thread laforge
Attention is currently required from: fixeria.

laforge has posted comments on this change. ( 
https://gerrit.osmocom.org/c/osmo-bsc/+/32540 )

Change subject: bts: st_op_enabled_on_enter(): resume C0 power reduction
..


Patch Set 2: Code-Review+2


--
To view, visit https://gerrit.osmocom.org/c/osmo-bsc/+/32540
To unsubscribe, or for help writing mail filters, visit 
https://gerrit.osmocom.org/settings

Gerrit-Project: osmo-bsc
Gerrit-Branch: master
Gerrit-Change-Id: Ic3f8a2ab0ffd049a8ed84361a3a588c1e1b23ac6
Gerrit-Change-Number: 32540
Gerrit-PatchSet: 2
Gerrit-Owner: fixeria 
Gerrit-Reviewer: Jenkins Builder
Gerrit-Reviewer: laforge 
Gerrit-Reviewer: pespin 
Gerrit-Attention: fixeria 
Gerrit-Comment-Date: Sat, 29 Apr 2023 22:16:18 +
Gerrit-HasComments: No
Gerrit-Has-Labels: Yes
Gerrit-MessageType: comment


[S] Change in osmo-bsc[master]: bootstrap_rsl(): cosmetic: cache trx->bts and use it directly

2023-04-29 Thread laforge
Attention is currently required from: fixeria.

laforge has posted comments on this change. ( 
https://gerrit.osmocom.org/c/osmo-bsc/+/32539 )

Change subject: bootstrap_rsl(): cosmetic: cache trx->bts and use it directly
..


Patch Set 1: Code-Review+2


--
To view, visit https://gerrit.osmocom.org/c/osmo-bsc/+/32539
To unsubscribe, or for help writing mail filters, visit 
https://gerrit.osmocom.org/settings

Gerrit-Project: osmo-bsc
Gerrit-Branch: master
Gerrit-Change-Id: I736ebf185028976dad5ff6f61386b6d2eeab8fbd
Gerrit-Change-Number: 32539
Gerrit-PatchSet: 1
Gerrit-Owner: fixeria 
Gerrit-Reviewer: Jenkins Builder
Gerrit-Reviewer: laforge 
Gerrit-Reviewer: pespin 
Gerrit-Attention: fixeria 
Gerrit-Comment-Date: Sat, 29 Apr 2023 22:14:38 +
Gerrit-HasComments: No
Gerrit-Has-Labels: Yes
Gerrit-MessageType: comment


[S] Change in osmo-bsc[master]: struct gsm_bts_model: rename power_ctrl_{set->send}_c0_power_red

2023-04-29 Thread laforge
Attention is currently required from: fixeria.

laforge has posted comments on this change. ( 
https://gerrit.osmocom.org/c/osmo-bsc/+/32538 )

Change subject: struct gsm_bts_model: rename power_ctrl_{set->send}_c0_power_red
..


Patch Set 1: Code-Review+2


--
To view, visit https://gerrit.osmocom.org/c/osmo-bsc/+/32538
To unsubscribe, or for help writing mail filters, visit 
https://gerrit.osmocom.org/settings

Gerrit-Project: osmo-bsc
Gerrit-Branch: master
Gerrit-Change-Id: I13d9e6ea2a2b7b11f92532d377e71f0e83974622
Gerrit-Change-Number: 32538
Gerrit-PatchSet: 1
Gerrit-Owner: fixeria 
Gerrit-Reviewer: Jenkins Builder
Gerrit-Reviewer: laforge 
Gerrit-Reviewer: pespin 
Gerrit-Attention: fixeria 
Gerrit-Comment-Date: Sat, 29 Apr 2023 22:14:21 +
Gerrit-HasComments: No
Gerrit-Has-Labels: Yes
Gerrit-MessageType: comment


[S] Change in osmo-bsc[master]: bts_is_online(): make the BTS pointer const, return bool

2023-04-29 Thread laforge
Attention is currently required from: fixeria.

laforge has posted comments on this change. ( 
https://gerrit.osmocom.org/c/osmo-bsc/+/32537 )

Change subject: bts_is_online(): make the BTS pointer const, return bool
..


Patch Set 1: Code-Review+2


--
To view, visit https://gerrit.osmocom.org/c/osmo-bsc/+/32537
To unsubscribe, or for help writing mail filters, visit 
https://gerrit.osmocom.org/settings

Gerrit-Project: osmo-bsc
Gerrit-Branch: master
Gerrit-Change-Id: Idb4f9f8862041c5902df0e6e8d1ac2a60ada95df
Gerrit-Change-Number: 32537
Gerrit-PatchSet: 1
Gerrit-Owner: fixeria 
Gerrit-Reviewer: Jenkins Builder
Gerrit-Reviewer: laforge 
Gerrit-Reviewer: pespin 
Gerrit-Attention: fixeria 
Gerrit-Comment-Date: Sat, 29 Apr 2023 22:13:55 +
Gerrit-HasComments: No
Gerrit-Has-Labels: Yes
Gerrit-MessageType: comment


[S] Change in libosmo-abis[master]: trau_pcu_ericsson: set uplink frame error bit correctly

2023-04-29 Thread laforge
laforge has submitted this change. ( 
https://gerrit.osmocom.org/c/libosmo-abis/+/32542 )

Change subject: trau_pcu_ericsson: set uplink frame error bit correctly
..

trau_pcu_ericsson: set uplink frame error bit correctly

At the moment we set the uplink frame error bit to 1 if ul_frame_err
is set to false. Unfortunately the er_gprs_trau_frame_encode pre set
all non T0 bits to 1 before calling the encoder function. This means
that with this logic the uplink frame error bit can never be set to 0.

Related: OS#6015
Change-Id: I74f56bc40ed074eb1588b202849870e2786ded24
---
M src/trau/trau_pcu_ericsson.c
1 file changed, 25 insertions(+), 10 deletions(-)

Approvals:
  Jenkins Builder: Verified
  pespin: Looks good to me, but someone else must approve
  laforge: Looks good to me, approved




diff --git a/src/trau/trau_pcu_ericsson.c b/src/trau/trau_pcu_ericsson.c
index 585e847..8f2e2a2 100644
--- a/src/trau/trau_pcu_ericsson.c
+++ b/src/trau/trau_pcu_ericsson.c
@@ -500,8 +500,8 @@
/* C-Bits */
osmo_pbit2ubit_ext(trau_bits, 17, _1_5, 0, 5, 1);
osmo_pbit2ubit_ext(trau_bits, 22, (pbit_t *) >tav, 0, 2, 1);
-   if (ind->ul_frame_err == false)
-   trau_bits[24] = 1;
+   if (ind->ul_frame_err)
+   trau_bits[24] = 0;
trau_bits[25] = calc_parity(trau_bits + 17, 8);

/* D-Bits */
@@ -555,8 +555,8 @@
/* C-Bits */
osmo_pbit2ubit_ext(trau_bits, 17, _1_5, 0, 5, 1);
osmo_pbit2ubit_ext(trau_bits, 22, (pbit_t *) >tav, 0, 2, 1);
-   if (ind->ul_frame_err == false)
-   trau_bits[24] = 1;
+   if (ind->ul_frame_err)
+   trau_bits[24] = 0;
trau_bits[25] = calc_parity(trau_bits + 17, 8);

/* Set coding scheme (E1-E2) */
@@ -1063,8 +1063,8 @@
/* C-Bits */
osmo_pbit2ubit_ext(trau_bits, 65, _1_5, 0, 5, 1);
osmo_pbit2ubit_ext(trau_bits, 70, (pbit_t *) >tav, 0, 2, 1);
-   if (ind->ul_frame_err == false)
-   trau_bits[73] = 1;
+   if (ind->ul_frame_err)
+   trau_bits[73] = 0;
trau_bits[74] = calc_parity(trau_bits + 65, 8);

/* Set unused D-Bits to 1 */
@@ -1135,8 +1135,8 @@
/* C-Bits */
osmo_pbit2ubit_ext(trau_bits, 65, _1_5, 0, 5, 1);
osmo_pbit2ubit_ext(trau_bits, 70, (pbit_t *) >tav, 0, 2, 1);
-   if (ind->ul_frame_err == false)
-   trau_bits[73] = 1;
+   if (ind->ul_frame_err)
+   trau_bits[73] = 0;
trau_bits[74] = calc_parity(trau_bits + 65, 8);

/* Set coding scheme (E1-E3) */
@@ -1321,8 +1321,8 @@
/* C-Bits */
osmo_pbit2ubit_ext(trau_bits, 65, _1_5, 0, 5, 1);
osmo_pbit2ubit_ext(trau_bits, 70, (pbit_t *) >tav, 0, 2, 1);
-   if (ind->ul_frame_err == false)
-   trau_bits[73] = 1;
+   if (ind->ul_frame_err)
+   trau_bits[73] = 0;
trau_bits[74] = calc_parity(trau_bits + 65, 8);

/* Set demodulation in uplink (E1-E3) */

--
To view, visit https://gerrit.osmocom.org/c/libosmo-abis/+/32542
To unsubscribe, or for help writing mail filters, visit 
https://gerrit.osmocom.org/settings

Gerrit-Project: libosmo-abis
Gerrit-Branch: master
Gerrit-Change-Id: I74f56bc40ed074eb1588b202849870e2786ded24
Gerrit-Change-Number: 32542
Gerrit-PatchSet: 1
Gerrit-Owner: dexter 
Gerrit-Reviewer: Jenkins Builder
Gerrit-Reviewer: keith 
Gerrit-Reviewer: laforge 
Gerrit-Reviewer: pespin 
Gerrit-MessageType: merged


[S] Change in libosmo-abis[master]: trau_pcu_ericsson: do not set unused D bits to 1

2023-04-29 Thread laforge
Attention is currently required from: keith, dexter.

laforge has posted comments on this change. ( 
https://gerrit.osmocom.org/c/libosmo-abis/+/32543 )

Change subject: trau_pcu_ericsson: do not set unused D bits to 1
..


Patch Set 1: Code-Review+1

(1 comment)

File src/trau/trau_pcu_ericsson.c:

https://gerrit.osmocom.org/c/libosmo-abis/+/32543/comment/12c8f5d3_a7c2dcbe 
PS1, Line 1071: memset(trau_bi
might make sense to have a comment here that this is done elsewhere.



--
To view, visit https://gerrit.osmocom.org/c/libosmo-abis/+/32543
To unsubscribe, or for help writing mail filters, visit 
https://gerrit.osmocom.org/settings

Gerrit-Project: libosmo-abis
Gerrit-Branch: master
Gerrit-Change-Id: I003632a08cc80bc195b306bef5f907351b6fe94e
Gerrit-Change-Number: 32543
Gerrit-PatchSet: 1
Gerrit-Owner: dexter 
Gerrit-Reviewer: Jenkins Builder
Gerrit-Reviewer: keith 
Gerrit-Reviewer: laforge 
Gerrit-Reviewer: pespin 
Gerrit-Attention: keith 
Gerrit-Attention: dexter 
Gerrit-Comment-Date: Sat, 29 Apr 2023 22:13:24 +
Gerrit-HasComments: Yes
Gerrit-Has-Labels: Yes
Gerrit-MessageType: comment


[S] Change in libosmo-abis[master]: trau_pcu_ericsson: set uplink frame error bit correctly

2023-04-29 Thread laforge
Attention is currently required from: keith, dexter.

laforge has posted comments on this change. ( 
https://gerrit.osmocom.org/c/libosmo-abis/+/32542 )

Change subject: trau_pcu_ericsson: set uplink frame error bit correctly
..


Patch Set 1: Code-Review+2


--
To view, visit https://gerrit.osmocom.org/c/libosmo-abis/+/32542
To unsubscribe, or for help writing mail filters, visit 
https://gerrit.osmocom.org/settings

Gerrit-Project: libosmo-abis
Gerrit-Branch: master
Gerrit-Change-Id: I74f56bc40ed074eb1588b202849870e2786ded24
Gerrit-Change-Number: 32542
Gerrit-PatchSet: 1
Gerrit-Owner: dexter 
Gerrit-Reviewer: Jenkins Builder
Gerrit-Reviewer: keith 
Gerrit-Reviewer: laforge 
Gerrit-Reviewer: pespin 
Gerrit-Attention: keith 
Gerrit-Attention: dexter 
Gerrit-Comment-Date: Sat, 29 Apr 2023 22:12:45 +
Gerrit-HasComments: No
Gerrit-Has-Labels: Yes
Gerrit-MessageType: comment


[S] Change in osmo-bsc[master]: fix mscpool for large msc NRs

2023-04-29 Thread fixeria
Attention is currently required from: neels.

fixeria has posted comments on this change. ( 
https://gerrit.osmocom.org/c/osmo-bsc/+/32554 )

Change subject: fix mscpool for large msc NRs
..


Patch Set 1: Code-Review+2


--
To view, visit https://gerrit.osmocom.org/c/osmo-bsc/+/32554
To unsubscribe, or for help writing mail filters, visit 
https://gerrit.osmocom.org/settings

Gerrit-Project: osmo-bsc
Gerrit-Branch: master
Gerrit-Change-Id: I98bee022c1a78508554d2ff4a10fbce3c53f1128
Gerrit-Change-Number: 32554
Gerrit-PatchSet: 1
Gerrit-Owner: neels 
Gerrit-Reviewer: Jenkins Builder
Gerrit-Reviewer: fixeria 
Gerrit-Attention: neels 
Gerrit-Comment-Date: Sat, 29 Apr 2023 08:30:39 +
Gerrit-HasComments: No
Gerrit-Has-Labels: Yes
Gerrit-MessageType: comment


[S] Change in osmo-bsc[master]: fix length check in abis_rsl_rx_rll()

2023-04-29 Thread fixeria
Attention is currently required from: neels, msuraev.

fixeria has posted comments on this change. ( 
https://gerrit.osmocom.org/c/osmo-bsc/+/32421 )

Change subject: fix length check in abis_rsl_rx_rll()
..


Patch Set 2: Code-Review+2


--
To view, visit https://gerrit.osmocom.org/c/osmo-bsc/+/32421
To unsubscribe, or for help writing mail filters, visit 
https://gerrit.osmocom.org/settings

Gerrit-Project: osmo-bsc
Gerrit-Branch: master
Gerrit-Change-Id: Ie4aee615c8c904ae8308ec0074d8bc5208137061
Gerrit-Change-Number: 32421
Gerrit-PatchSet: 2
Gerrit-Owner: neels 
Gerrit-Reviewer: Jenkins Builder
Gerrit-Reviewer: fixeria 
Gerrit-Reviewer: pespin 
Gerrit-CC: msuraev 
Gerrit-Attention: neels 
Gerrit-Attention: msuraev 
Gerrit-Comment-Date: Sat, 29 Apr 2023 08:30:10 +
Gerrit-HasComments: No
Gerrit-Has-Labels: Yes
Gerrit-MessageType: comment


[M] Change in osmo-bts[master]: gsm_objclass2mo(): Change signature/set NACK cause

2023-04-29 Thread fixeria
Attention is currently required from: arehbein, laforge, pespin.

fixeria has posted comments on this change. ( 
https://gerrit.osmocom.org/c/osmo-bts/+/32075 )

Change subject: gsm_objclass2mo(): Change signature/set NACK cause
..


Patch Set 8:

(2 comments)

File src/common/oml.c:

https://gerrit.osmocom.org/c/osmo-bts/+/32075/comment/4169c6e8_4fe98223
PS8, Line 1107: return oml_fom_ack_nack(msg, 
NM_NACK_OBJINST_UNKN);
> you are missing passing "c" here instead of fixed NM_NACK_OBJINST_UNKN.
NACK


https://gerrit.osmocom.org/c/osmo-bts/+/32075/comment/cbec9d04_341146e9
PS8, Line 1153: return oml_fom_ack_nack(msg, 
NM_NACK_OBJINST_UNKN);
> same, missing passing "c".
NACK



--
To view, visit https://gerrit.osmocom.org/c/osmo-bts/+/32075
To unsubscribe, or for help writing mail filters, visit 
https://gerrit.osmocom.org/settings

Gerrit-Project: osmo-bts
Gerrit-Branch: master
Gerrit-Change-Id: I37e6b23ed95260a8188910cf9754faffcba519c5
Gerrit-Change-Number: 32075
Gerrit-PatchSet: 8
Gerrit-Owner: arehbein 
Gerrit-Reviewer: Jenkins Builder
Gerrit-Reviewer: fixeria 
Gerrit-Reviewer: pespin 
Gerrit-CC: laforge 
Gerrit-Attention: arehbein 
Gerrit-Attention: laforge 
Gerrit-Attention: pespin 
Gerrit-Comment-Date: Sat, 29 Apr 2023 07:54:58 +
Gerrit-HasComments: Yes
Gerrit-Has-Labels: No
Comment-In-Reply-To: pespin 
Gerrit-MessageType: comment


[S] Change in osmo-bts[master]: fixup: common: Remove unused function gsm_objclass2nmstate()

2023-04-29 Thread fixeria
fixeria has submitted this change. ( 
https://gerrit.osmocom.org/c/osmo-bts/+/32553 )

Change subject: fixup: common: Remove unused function gsm_objclass2nmstate()
..

fixup: common: Remove unused function gsm_objclass2nmstate()

Change-Id: I31b948f2aeb18ac8069fc019285be7991cffe064
---
M include/osmo-bts/oml.h
1 file changed, 9 insertions(+), 2 deletions(-)

Approvals:
  Jenkins Builder: Verified
  pespin: Looks good to me, approved




diff --git a/include/osmo-bts/oml.h b/include/osmo-bts/oml.h
index c59f6ba..38568b5 100644
--- a/include/osmo-bts/oml.h
+++ b/include/osmo-bts/oml.h
@@ -80,8 +80,6 @@
 struct gsm_abis_mo *gsm_objclass2mo(struct gsm_bts *bts, uint8_t obj_class,
const struct abis_om_obj_inst *obj_inst);

-struct gsm_nm_state *gsm_objclass2nmstate(struct gsm_bts *bts, uint8_t 
obj_class,
- const struct abis_om_obj_inst 
*obj_inst);
 void *gsm_objclass2obj(struct gsm_bts *bts, uint8_t obj_class,
   const struct abis_om_obj_inst *obj_inst);


diff --git a/src/common/oml.c b/src/common/oml.c
index 6bdb49b..7ab1bc2 100644
--- a/src/common/oml.c
+++ b/src/common/oml.c
@@ -1103,8 +1103,8 @@
/* Step 1: Resolve MO by obj_class/obj_inst */
if ((mo = gsm_objclass2mo(bts, foh->obj_class, >obj_inst, )) == 
NULL)
return oml_fom_ack_nack(msg, c);
-   if ((obj = gsm_objclass2obj(bts, foh->obj_class, >obj_inst)) == 
NULL)
-   return oml_fom_ack_nack(msg, NM_NACK_OBJINST_UNKN);
+   if ((obj = gsm_objclass2obj(bts, foh->obj_class, >obj_inst, )) 
== NULL)
+   return oml_fom_ack_nack(msg, c);

/* Step 2: Do some global dependency/consistency checking */
if (mo->nm_state.operational == NM_OPSTATE_ENABLED) {
@@ -1149,8 +1149,8 @@
/* Step 1: Resolve MO by obj_class/obj_inst */
if ((mo = gsm_objclass2mo(bts, foh->obj_class, >obj_inst, )) == 
NULL)
return oml_fom_ack_nack(msg, c);
-   if ((obj = gsm_objclass2obj(bts, foh->obj_class, >obj_inst)) == 
NULL)
-   return oml_fom_ack_nack(msg, NM_NACK_OBJINST_UNKN);
+   if ((obj = gsm_objclass2obj(bts, foh->obj_class, >obj_inst, )) 
== NULL)
+   return oml_fom_ack_nack(msg, c);

/* Step 2: Do some global dependency/consistency checking */
if (mo->nm_state.administrative == adm_state) {
@@ -1491,8 +1491,8 @@
/* Resolve MO by obj_class/obj_inst */
if ((mo = gsm_objclass2mo(bts, foh->obj_class, >obj_inst, )) == 
NULL)
return oml_fom_ack_nack(msg, c);
-   if ((obj = gsm_objclass2obj(bts, foh->obj_class, >obj_inst)) == 
NULL)
-   return oml_fom_ack_nack(msg, NM_NACK_OBJINST_UNKN);
+   if ((obj = gsm_objclass2obj(bts, foh->obj_class, >obj_inst, )) 
== NULL)
+   return oml_fom_ack_nack(msg, c);


switch (mo->obj_class) {
@@ -1793,10 +1793,11 @@
return NULL;
 }

-/* obtain the in-memory data structure of a given object instance */
-void *
-gsm_objclass2obj(struct gsm_bts *bts, uint8_t obj_class,
-const struct abis_om_obj_inst *obj_inst)
+/* Obtain the in-memory data structure of a given object instance
+ *  \param[out] c nack cause for reply in case of error. Ignored if NULL */
+void *gsm_objclass2obj(struct gsm_bts *bts, uint8_t obj_class,
+  const struct abis_om_obj_inst *obj_inst,
+  enum abis_nm_nack_cause *c)
 {
struct gsm_bts_trx *trx;
void *obj = NULL;
@@ -1807,19 +1808,19 @@
break;
case NM_OC_RADIO_CARRIER:
if (!(trx = gsm_bts_trx_num(bts, obj_inst->trx_nr)))
-   return NULL;
+   goto nm_nack_trxnr_unkn;
obj = trx;
break;
case NM_OC_BASEB_TRANSC:
if (!(trx = gsm_bts_trx_num(bts, obj_inst->trx_nr)))
-   return NULL;
+   goto nm_nack_trxnr_unkn;
obj = >bb_transc;
break;
case NM_OC_CHANNEL:
if (!(trx = gsm_bts_trx_num(bts, obj_inst->trx_nr)))
-   return NULL;
+   goto nm_nack_trxnr_unkn;
if (obj_inst->ts_nr >= TRX_NR_TS)
-   return NULL;
+   goto nm_nack_objinst_unkn;
obj = >ts[obj_inst->ts_nr];
break;
case NM_OC_SITE_MANAGER:
@@ -1827,7 +1828,7 @@
break;
case NM_OC_GPRS_NSE:
if (obj_inst->bts_nr > 0)
-   return NULL;
+

[M] Change in osmo-bts[master]: gsm_objclass2mo(): Change signature/set NACK cause

2023-04-29 Thread fixeria
fixeria has submitted this change. ( 
https://gerrit.osmocom.org/c/osmo-bts/+/32075 )

Change subject: gsm_objclass2mo(): Change signature/set NACK cause
..

gsm_objclass2mo(): Change signature/set NACK cause

 - Add out-parameter to enable returning a NACK cause (ignored if NULL)
 - Return appropriate NACK cause if TRX number is unknown (part of fix
   for OS#5967)

Change-Id: I37e6b23ed95260a8188910cf9754faffcba519c5
Related: OS#5961, OS#5967
---
M include/osmo-bts/oml.h
M src/common/oml.c
2 files changed, 54 insertions(+), 27 deletions(-)

Approvals:
  Jenkins Builder: Verified
  pespin: Looks good to me, but someone else must approve
  laforge: Looks good to me, but someone else must approve
  fixeria: Looks good to me, approved




--
To view, visit https://gerrit.osmocom.org/c/osmo-bts/+/32553
To unsubscribe, or for help writing mail filters, visit 
https://gerrit.osmocom.org/settings

Gerrit-Project: osmo-bts
Gerrit-Branch: master
Gerrit-Change-Id: I31b948f2aeb18ac8069fc019285be7991cffe064
Gerrit-Change-Number: 32553
Gerrit-PatchSet: 1
Gerrit-Owner: fixeria 
Gerrit-Reviewer: Jenkins Builder
Gerrit-Reviewer: fixeria 
Gerrit-Reviewer: pespin 
Gerrit-MessageType: merged


[S] Change in osmo-bts[master]: osmo-bts-trx: fix trx_ctrl_read_cb(): do not send CMDs twice

2023-04-29 Thread fixeria
Attention is currently required from: pespin.

fixeria has posted comments on this change. ( 
https://gerrit.osmocom.org/c/osmo-bts/+/32552 )

Change subject: osmo-bts-trx: fix trx_ctrl_read_cb(): do not send CMDs twice
..


Patch Set 2:

(1 comment)

File src/osmo-bts-trx/trx_if.c:

https://gerrit.osmocom.org/c/osmo-bts/+/32552/comment/67b03158_3750c81f
PS1, Line 743: re-schedule last cmd in rc seconds time
I am wondering how this is supposed to work, given that we have unlinked the 
last cmd at this point already... This looks really weird.



--
To view, visit https://gerrit.osmocom.org/c/osmo-bts/+/32552
To unsubscribe, or for help writing mail filters, visit 
https://gerrit.osmocom.org/settings

Gerrit-Project: osmo-bts
Gerrit-Branch: master
Gerrit-Change-Id: Ibdffa4644aa3a7d219452644d3e74b411734f1df
Gerrit-Change-Number: 32552
Gerrit-PatchSet: 2
Gerrit-Owner: fixeria 
Gerrit-Reviewer: Jenkins Builder
Gerrit-CC: pespin 
Gerrit-Attention: pespin 
Gerrit-Comment-Date: Sat, 29 Apr 2023 07:54:06 +
Gerrit-HasComments: Yes
Gerrit-Has-Labels: No
Gerrit-MessageType: comment


[S] Change in osmo-bts[master]: osmo-bts-trx: fix trx_ctrl_read_cb(): do not send CMDs twice

2023-04-29 Thread fixeria
Attention is currently required from: pespin.

fixeria has posted comments on this change. ( 
https://gerrit.osmocom.org/c/osmo-bts/+/32552 )

Change subject: osmo-bts-trx: fix trx_ctrl_read_cb(): do not send CMDs twice
..


Patch Set 2:

(1 comment)

File src/osmo-bts-trx/trx_if.c:

https://gerrit.osmocom.org/c/osmo-bts/+/32552/comment/c381a351_47a48f80
PS1, Line 737:
> what about moving "trx_ctrl_send(l1h);" here before call to 
> trx_ctrl_rx_rsp()? this way we don't get […]
I was thinking about this too. But this would make the logging/flow a bit 
confusing:

* first we say we received a response for previously sent command,
* then we send the next command from the queue,
* and then we handle the received response for previous command.

IMO, it's more logical as it is now.



--
To view, visit https://gerrit.osmocom.org/c/osmo-bts/+/32552
To unsubscribe, or for help writing mail filters, visit 
https://gerrit.osmocom.org/settings

Gerrit-Project: osmo-bts
Gerrit-Branch: master
Gerrit-Change-Id: Ibdffa4644aa3a7d219452644d3e74b411734f1df
Gerrit-Change-Number: 32552
Gerrit-PatchSet: 2
Gerrit-Owner: fixeria 
Gerrit-Reviewer: Jenkins Builder
Gerrit-CC: pespin 
Gerrit-Attention: pespin 
Gerrit-Comment-Date: Sat, 29 Apr 2023 07:48:14 +
Gerrit-HasComments: Yes
Gerrit-Has-Labels: No
Comment-In-Reply-To: pespin 
Gerrit-MessageType: comment


[S] Change in osmo-bts[master]: osmo-bts-trx: fix trx_ctrl_read_cb(): do not send CMDs twice

2023-04-29 Thread fixeria
Attention is currently required from: pespin.

Hello Jenkins Builder,

I'd like you to reexamine a change. Please visit

https://gerrit.osmocom.org/c/osmo-bts/+/32552

to look at the new patch set (#2).

Change subject: osmo-bts-trx: fix trx_ctrl_read_cb(): do not send CMDs twice
..

osmo-bts-trx: fix trx_ctrl_read_cb(): do not send CMDs twice

Sometimes osmo-bts-trx may be sending the same TRXC CMD twice.  This
happens when the trx_ctrl_list becomes empty in trx_ctrl_read_cb(),
and a command specific response handler enqueues more commands.

The problem is that in trx_ctrl_cmd_cb() we send() the given command
stright away, if the trx_ctrl_list is empty.  This must be taken into
account in trx_ctrl_read_cb() when calling trx_ctrl_send().

Change-Id: Ibdffa4644aa3a7d219452644d3e74b411734f1df
Fixes: OS#6020
---
M src/osmo-bts-trx/trx_if.c
1 file changed, 28 insertions(+), 1 deletion(-)


  git pull ssh://gerrit.osmocom.org:29418/osmo-bts refs/changes/52/32552/2
--
To view, visit https://gerrit.osmocom.org/c/osmo-bts/+/32552
To unsubscribe, or for help writing mail filters, visit 
https://gerrit.osmocom.org/settings

Gerrit-Project: osmo-bts
Gerrit-Branch: master
Gerrit-Change-Id: Ibdffa4644aa3a7d219452644d3e74b411734f1df
Gerrit-Change-Number: 32552
Gerrit-PatchSet: 2
Gerrit-Owner: fixeria 
Gerrit-Reviewer: Jenkins Builder
Gerrit-CC: pespin 
Gerrit-Attention: pespin 
Gerrit-MessageType: newpatchset


[S] Change in osmo-bts[master]: osmo-bts-trx: fix trx_ctrl_read_cb(): do not send CMDs twice

2023-04-29 Thread fixeria
Attention is currently required from: pespin.

fixeria has posted comments on this change. ( 
https://gerrit.osmocom.org/c/osmo-bts/+/32552 )

Change subject: osmo-bts-trx: fix trx_ctrl_read_cb(): do not send CMDs twice
..


Patch Set 1:

(3 comments)

File src/osmo-bts-trx/trx_if.c:

https://gerrit.osmocom.org/c/osmo-bts/+/32552/comment/34988df9_f0880039
PS1, Line 732:  /* Calling trx_ctrl_rx_rsp() may trigger code patch(s) queueing 
more CMDs.
> typo: path
Done


https://gerrit.osmocom.org/c/osmo-bts/+/32552/comment/ed7e9dad_e2653ea5
PS1, Line 736:  more_cmds = !llist_empty(>trx_ctrl_list);
> It would be much more clearing storing this in a var called list_was_empty = 
> llist_empty()
Ack


https://gerrit.osmocom.org/c/osmo-bts/+/32552/comment/f71beec7_b236ada6
PS1, Line 751:  if (more_cmds)
> Nevermind this comment.
This would not solve the problem of sending the same CMD twice.



--
To view, visit https://gerrit.osmocom.org/c/osmo-bts/+/32552
To unsubscribe, or for help writing mail filters, visit 
https://gerrit.osmocom.org/settings

Gerrit-Project: osmo-bts
Gerrit-Branch: master
Gerrit-Change-Id: Ibdffa4644aa3a7d219452644d3e74b411734f1df
Gerrit-Change-Number: 32552
Gerrit-PatchSet: 1
Gerrit-Owner: fixeria 
Gerrit-Reviewer: Jenkins Builder
Gerrit-CC: pespin 
Gerrit-Attention: pespin 
Gerrit-Comment-Date: Sat, 29 Apr 2023 07:32:49 +
Gerrit-HasComments: Yes
Gerrit-Has-Labels: No
Comment-In-Reply-To: pespin 
Gerrit-MessageType: comment